@@ -137,9 +137,13 @@ void CtActions::preferences_import()
     auto pConfig = _pCtMainWin->get_ct_config();
 
     pConfig->toolbarVisible = ctConfigImported.toolbarVisible;
+    pConfig->statusbarVisible = ctConfigImported.statusbarVisible;
+    pConfig->treeLinesVisible = ctConfigImported.treeLinesVisible;
     pConfig->hpanedPos = ctConfigImported.hpanedPos;
     pConfig->treeVisible = ctConfigImported.treeVisible;
+    pConfig->menubarVisible = ctConfigImported.menubarVisible;
     pConfig->linkType = ctConfigImported.linkType;
+    pConfig->menubarInTitlebar = ctConfigImported.menubarInTitlebar;
     pConfig->showNodeNameHeader = ctConfigImported.showNodeNameHeader;
     pConfig->nodesOnNodeNameHeader = ctConfigImported.nodesOnNodeNameHeader;
     pConfig->toolbarIconSize = ctConfigImported.toolbarIconSize;
@@ -222,6 +226,8 @@ void CtActions::preferences_import()
     pConfig->codeFont = ctConfigImported.codeFont;
     pConfig->ttDefFg = ctConfigImported.ttDefFg;
     pConfig->ttDefBg = ctConfigImported.ttDefBg;
+    pConfig->ttSelFg = ctConfigImported.ttSelFg;
+    pConfig->ttSelBg = ctConfigImported.ttSelBg;
     pConfig->scalableH1.deserialise(ctConfigImported.scalableH1.serialise().c_str());
     pConfig->scalableH2.deserialise(ctConfigImported.scalableH2.serialise().c_str());
     pConfig->scalableH3.deserialise(ctConfigImported.scalableH3.serialise().c_str());
@@ -233,7 +239,6 @@ void CtActions::preferences_import()
     pConfig->monospaceBg = ctConfigImported.monospaceBg;
     pConfig->msDedicatedFont = ctConfigImported.msDedicatedFont;
     pConfig->monospaceFont = ctConfigImported.monospaceFont;
-    pConfig->colorPalette = ctConfigImported.colorPalette;
     pConfig->colLinkWebs = ctConfigImported.colLinkWebs;
     pConfig->colLinkNode = ctConfigImported.colLinkNode;
     pConfig->colLinkFile = ctConfigImported.colLinkFile;
