@@ -29,9 +29,10 @@
 // Toggle Show/Hide the Tree
 void CtActions::toggle_show_hide_tree()
 {
-    _pCtMainWin->get_ct_config()->treeVisible = !_pCtMainWin->get_ct_config()->treeVisible;
-    _pCtMainWin->show_hide_tree_view(_pCtMainWin->get_ct_config()->treeVisible);
-    if (_pCtMainWin->get_ct_config()->treeVisible) {
+    auto pCtConfig = _pCtMainWin->get_ct_config();
+    pCtConfig->treeVisible = not pCtConfig->treeVisible;
+    _pCtMainWin->show_hide_tree_view(pCtConfig->treeVisible);
+    if (pCtConfig->treeVisible) {
         _pCtMainWin->get_tree_view().grab_focus();
     }
     else {
@@ -39,17 +40,39 @@ void CtActions::toggle_show_hide_tree()
     }
 }
 
-// Toggle Show/Hide the Toolbar
+void CtActions::toggle_show_hide_menubar()
+{
+    auto pCtConfig = _pCtMainWin->get_ct_config();
+    pCtConfig->menubarVisible = not pCtConfig->menubarVisible;
+    _pCtMainWin->show_hide_menubar(pCtConfig->menubarVisible);
+}
+
 void CtActions::toggle_show_hide_toolbars()
 {
-    _pCtMainWin->get_ct_config()->toolbarVisible = !_pCtMainWin->get_ct_config()->toolbarVisible;
-    _pCtMainWin->show_hide_toolbars(_pCtMainWin->get_ct_config()->toolbarVisible);
+    auto pCtConfig = _pCtMainWin->get_ct_config();
+    pCtConfig->toolbarVisible = not pCtConfig->toolbarVisible;
+    _pCtMainWin->show_hide_toolbars(pCtConfig->toolbarVisible);
+}
+
+void CtActions::toggle_show_hide_statusbar()
+{
+    auto pCtConfig = _pCtMainWin->get_ct_config();
+    pCtConfig->statusbarVisible = not pCtConfig->statusbarVisible;
+    _pCtMainWin->show_hide_statusbar(pCtConfig->statusbarVisible);
 }
 
 void CtActions::toggle_show_hide_node_name_header()
 {
-    _pCtMainWin->get_ct_config()->showNodeNameHeader = !_pCtMainWin->get_ct_config()->showNodeNameHeader;
-    _pCtMainWin->show_hide_win_header(_pCtMainWin->get_ct_config()->showNodeNameHeader);
+    auto pCtConfig = _pCtMainWin->get_ct_config();
+    pCtConfig->showNodeNameHeader = not pCtConfig->showNodeNameHeader;
+    _pCtMainWin->show_hide_win_header(pCtConfig->showNodeNameHeader);
+}
+
+void CtActions::toggle_show_hide_tree_lines()
+{
+    auto pCtConfig = _pCtMainWin->get_ct_config();
+    pCtConfig->treeLinesVisible = not pCtConfig->treeLinesVisible;
+    _pCtMainWin->show_hide_tree_lines(pCtConfig->treeLinesVisible);
 }
 
 // Toggle Focus Between Tree and Text
@@ -98,10 +121,27 @@ void CtActions::toolbar_icons_size_decrease()
 // Toggle Fullscreen State
 void CtActions::fullscreen_toggle()
 {
-    if (_pCtMainWin->get_window()->get_state() & GDK_WINDOW_STATE_FULLSCREEN) {
-        _pCtMainWin->unfullscreen();
+    if (_pCtMainWin->get_titlebar()) {
+        // unfullscreen doesn't work with the custom titlebar, so we can only maximise
+        if (_pCtMainWin->property_is_maximized()) {
+            _pCtMainWin->unmaximize();
+        }
+        else {
+            _pCtMainWin->maximize();
+        }
     }
     else {
-        _pCtMainWin->fullscreen();
+        if (_pCtMainWin->get_window()->get_state() & GDK_WINDOW_STATE_FULLSCREEN) {
+            _pCtMainWin->unfullscreen();
+        }
+        else {
+            _pCtMainWin->fullscreen();
+        }
     }
 }
+
+void CtActions::_menubar_in_titlebar_set(const bool setOn)
+{
+    _pCtMainWin->get_ct_config()->menubarInTitlebar = setOn;
+    CtDialogs::info_dialog(_("This Change will have Effect Only After Restarting CherryTree"), *_pCtMainWin);
+}
