@@ -1,7 +1,7 @@
 /*
  * ct_app.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -30,21 +30,22 @@
 
 #include "ct_config.h"
 #include "ct_main_win.h"
-#include "ct_menu.h"
 #include "ct_actions.h"
 #include "ct_export2pdf.h"
+#include "ct_widgets.h"
 
 class CtMainWin;
 class CtApp : public Gtk::Application
 {
 protected:
-    CtApp();
-    virtual ~CtApp() override;
+    CtApp(const char* application_id = "com.giuspen.cherrytree");
 
 public:
     static Glib::RefPtr<CtApp> create();
+    void                       close_all_windows(const bool userCanInteract = true);
+    void                       systray_show_hide_windows();
 
-private:
+protected:
     std::unique_ptr<CtConfig> _uCtCfg;
     std::unique_ptr<CtTmp> _uCtTmp;
     Glib::RefPtr<Gtk::IconTheme> _rIcontheme;
@@ -52,17 +53,19 @@ private:
     Glib::RefPtr<Gtk::CssProvider> _rCssProvider;
     Glib::RefPtr<Gsv::LanguageManager> _rLanguageManager;
     Glib::RefPtr<Gsv::StyleSchemeManager> _rStyleSchemeManager;
-    Glib::RefPtr<Gtk::StatusIcon> _rStatusIcon;
+    std::unique_ptr<CtStatusIcon> _uCtStatusIcon;
 
 protected:
     Glib::ustring _node_to_focus;
     std::string   _export_to_html_dir;
     std::string   _export_to_txt_dir;
-    std::string   _export_to_pdf_file;
+    std::string   _export_to_pdf_dir;
     bool          _export_overwrite{false};
     bool          _export_single_file{false};
     bool          _new_window{false};
     bool          _initDone{false};
+    bool          _no_gui{false};
+    std::mutex    _quitOrHideWinMutex;
 
 protected:
     void        on_activate() override;
@@ -76,9 +79,6 @@ protected:
 protected:
     CtMainWin*  _create_window(const bool no_gui = false);
     CtMainWin*  _get_window_by_path(const std::string& filepath);
-    bool        _quit_or_hide_window(CtMainWin* pCtMainWin, bool from_delete);
+    bool        _quit_or_hide_window(CtMainWin* pCtMainWin, const bool fromDelete, const bool fromKillCallback);
     int         _on_handle_local_options(const Glib::RefPtr<Glib::VariantDict>& rOptions);
-
-    void        _systray_show_hide_windows();
-    void        _systray_close_all();
 };
