@@ -35,38 +35,61 @@ const constexpr int MIN_SCROLL_HEIGHT = 47;
 CtTextCell::CtTextCell(CtMainWin* pCtMainWin,
                        const Glib::ustring& textContent,
                        const std::string& syntaxHighlighting)
- : _syntaxHighlighting(syntaxHighlighting),
-   _ctTextview(pCtMainWin)
+ : _syntaxHighlighting{syntaxHighlighting}
+ , _ctTextview{pCtMainWin}
 {
     _rTextBuffer = pCtMainWin->get_new_text_buffer(textContent);
     _ctTextview.set_buffer(_rTextBuffer);
     _ctTextview.setup_for_syntax(_syntaxHighlighting);
 
-    _rTextBuffer->signal_insert().connect([&](const Gtk::TextIter& pos, const Glib::ustring& text, int /*bytes*/) {
-        if (_ctTextview.getCtMainWin()->user_active() and not _ctTextview.own_insert_delete_active()) {
+    _rTextBuffer->signal_insert().connect([pCtMainWin, this](const Gtk::TextIter& pos, const Glib::ustring& text, int /*bytes*/) {
+        if (pCtMainWin->user_active() and not _ctTextview.own_insert_delete_active()) {
             _ctTextview.text_inserted(pos, text);
-            _ctTextview.getCtMainWin()->get_state_machine().text_variation(_ctTextview.getCtMainWin()->curr_tree_iter().get_node_id(), text);
-            _ctTextview.getCtMainWin()->update_window_save_needed(CtSaveNeededUpdType::nbuf);
+            pCtMainWin->get_state_machine().text_variation(pCtMainWin->curr_tree_iter().get_node_id(), text);
+            pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
         }
     }, false);
-    _rTextBuffer->signal_erase().connect([&](const Gtk::TextIter& range_start, const Gtk::TextIter& range_end) {
-        if (_ctTextview.getCtMainWin()->user_active() and not _ctTextview.own_insert_delete_active()) {
+    _rTextBuffer->signal_erase().connect([pCtMainWin, this](const Gtk::TextIter& range_start, const Gtk::TextIter& range_end) {
+        if (pCtMainWin->user_active() and not _ctTextview.own_insert_delete_active()) {
             _ctTextview.text_removed(range_start, range_end);
-            _ctTextview.getCtMainWin()->get_state_machine().text_variation(_ctTextview.getCtMainWin()->curr_tree_iter().get_node_id(), range_start.get_text(range_end));
-            _ctTextview.getCtMainWin()->update_window_save_needed(CtSaveNeededUpdType::nbuf);
+            pCtMainWin->get_state_machine().text_variation(pCtMainWin->curr_tree_iter().get_node_id(), range_start.get_text(range_end));
+            pCtMainWin->update_window_save_needed(CtSaveNeededUpdType::nbuf);
         }
     }, false);
-    _rTextBuffer->signal_mark_set().connect([&](const Gtk::TextIter& /*iter*/, const Glib::RefPtr<Gtk::TextMark>& rMark){
-        if (_ctTextview.getCtMainWin()->user_active()) {
+    _rTextBuffer->signal_mark_set().connect([pCtMainWin, this](const Gtk::TextIter& /*iter*/, const Glib::RefPtr<Gtk::TextMark>& rMark){
+        if (pCtMainWin->user_active()) {
+            _ctTextview.set_editable(not pCtMainWin->curr_tree_iter().get_node_read_only());
             if (rMark->get_name() == "insert") {
                 _ctTextview.selection_update();
             }
         }
     }, false);
-}
 
-CtTextCell::~CtTextCell()
-{
+    _ctTextview.signal_event_after().connect([pCtMainWin, this](GdkEvent* event){
+        if (not pCtMainWin->user_active()) return;
+        if (event->type == GDK_2BUTTON_PRESS and event->button.button == 1)
+            _ctTextview.for_event_after_double_click_button1(event);
+        else if (event->type == GDK_BUTTON_PRESS)
+            _ctTextview.for_event_after_button_press(event);
+        else if (event->type == GDK_KEY_PRESS)
+            _ctTextview.for_event_after_key_press(event, _syntaxHighlighting);
+    });
+    _ctTextview.signal_motion_notify_event().connect([pCtMainWin, this](GdkEventMotion* event){
+        if (not pCtMainWin->user_active()) return false;
+        int x, y;
+        _ctTextview.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, int(event->x), int(event->y), x, y);
+        _ctTextview.cursor_and_tooltips_handler(x, y);
+        return false;
+    });
+    _ctTextview.signal_scroll_event().connect([this](GdkEventScroll* event){
+        if (!(event->state & GDK_CONTROL_MASK))
+            return false;
+        if  (event->direction == GDK_SCROLL_UP || event->direction == GDK_SCROLL_DOWN)
+            _ctTextview.zoom_text(event->direction == GDK_SCROLL_DOWN, _syntaxHighlighting);
+        if  (event->direction == GDK_SCROLL_SMOOTH && event->delta_y != 0)
+            _ctTextview.zoom_text(event->delta_y < 0, _syntaxHighlighting);
+        return true;
+    });
 }
 
 Glib::ustring CtTextCell::get_text_content() const
@@ -104,20 +127,21 @@ CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
                      const bool widthInPixels,
                      const bool highlightBrackets,
                      const bool showLineNumbers)
- : CtAnchoredWidget(pCtMainWin, charOffset, justification),
-   CtTextCell(pCtMainWin, textContent, syntaxHighlighting),
-   _frameWidth(frameWidth),
-   _frameHeight(frameHeight),
-   _key_down(false)
+ : CtAnchoredWidget{pCtMainWin, charOffset, justification}
+ , CtTextCell{pCtMainWin, textContent, syntaxHighlighting}
+ , _frameWidth{frameWidth}
+ , _frameHeight{frameHeight}
 {
     _ctTextview.get_style_context()->add_class("ct-codebox");
     _ctTextview.set_border_width(1);
 
     if (!_pCtMainWin->get_ct_config()->codeboxAutoResize) {
-        if (_frameHeight < MIN_SCROLL_HEIGHT) /* overwise not possible to have 20 px height*/
+        if (_frameHeight < MIN_SCROLL_HEIGHT) { /* overwise not possible to have 20 px height*/
             _scrolledwindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_EXTERNAL /* overwise not possible to have 20 px height*/);
-        else
+        }
+        else {
             _scrolledwindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+        }
     } else {
         _scrolledwindow.set_policy(Gtk::POLICY_NEVER, Gtk::POLICY_NEVER);
         _ctTextview.set_wrap_mode(Gtk::WrapMode::WRAP_NONE);
@@ -128,8 +152,6 @@ CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
     _frame.signal_size_allocate().connect(sigc::mem_fun(*this, &CtCodebox::_on_size_allocate_frame));
     show_all();
 
-    _ctTextview.set_monospace(true); // todo: remove than styles are implemented
-
     set_width_in_pixels(widthInPixels);
     set_highlight_brackets(highlightBrackets);
     set_show_line_numbers(showLineNumbers);
@@ -142,7 +164,6 @@ CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
         _pCtMainWin->get_ct_menu().build_popup_menu(menu, CtMenu::POPUP_MENU_TYPE::Codebox);
     });
     _ctTextview.signal_key_press_event().connect(sigc::mem_fun(*this, &CtCodebox::_on_key_press_event), false);
-    _ctTextview.signal_key_release_event().connect([this](GdkEventKey*) { _key_down = false; return false; }, false);
     _ctTextview.signal_button_press_event().connect([this](GdkEventButton* event){
         if (not _pCtMainWin->user_active()) return false;
         _pCtMainWin->get_ct_actions()->curr_codebox_anchor = this;
@@ -153,41 +174,11 @@ CtCodebox::CtCodebox(CtMainWin* pCtMainWin,
         }
         return false;
     });
-    _ctTextview.signal_event_after().connect([this](GdkEvent* event){
-        if (not _pCtMainWin->user_active()) return;
-        if (event->type == GDK_2BUTTON_PRESS and event->button.button == 1)
-            _ctTextview.for_event_after_double_click_button1(event);
-        else if (event->type == GDK_BUTTON_PRESS)
-            _ctTextview.for_event_after_button_press(event);
-        else if (event->type == GDK_KEY_PRESS)
-            _ctTextview.for_event_after_key_press(event, _syntaxHighlighting);
-    });
-    _ctTextview.signal_motion_notify_event().connect([this](GdkEventMotion* event){
-        if (not _pCtMainWin->user_active()) return false;
-        _ctTextview.set_editable(!_pCtMainWin->curr_tree_iter().get_node_read_only());
-        int x, y;
-        _ctTextview.window_to_buffer_coords(Gtk::TEXT_WINDOW_TEXT, int(event->x), int(event->y), x, y);
-        _ctTextview.cursor_and_tooltips_handler(x, y);
-        return false;
-    });
-    _ctTextview.signal_scroll_event().connect([this](GdkEventScroll* event){
-        if (!(event->state & GDK_CONTROL_MASK))
-            return false;
-        if  (event->direction == GDK_SCROLL_UP || event->direction == GDK_SCROLL_DOWN)
-            _ctTextview.zoom_text(event->direction == GDK_SCROLL_DOWN, get_syntax_highlighting());
-        if  (event->direction == GDK_SCROLL_SMOOTH && event->delta_y != 0)
-            _ctTextview.zoom_text(event->delta_y < 0, get_syntax_highlighting());
-        return true;
-    });
     _uCtPairCodeboxMainWin.reset(new CtPairCodeboxMainWin{this, _pCtMainWin});
     g_signal_connect(G_OBJECT(_ctTextview.gobj()), "cut-clipboard", G_CALLBACK(CtClipboard::on_cut_clipboard), _uCtPairCodeboxMainWin.get());
     g_signal_connect(G_OBJECT(_ctTextview.gobj()), "copy-clipboard", G_CALLBACK(CtClipboard::on_copy_clipboard), _uCtPairCodeboxMainWin.get());
 }
 
-CtCodebox::~CtCodebox()
-{
-}
-
 void CtCodebox::apply_width_height(const int parentTextWidth)
 {
     int frameWidth = _widthInPixels ? _frameWidth : (parentTextWidth*_frameWidth)/100;
@@ -219,13 +210,11 @@ bool CtCodebox::to_sqlite(sqlite3* pDb, const gint64 node_id, const int offset_a
 {
     bool retVal{true};
     sqlite3_stmt *p_stmt;
-    if (sqlite3_prepare_v2(pDb, CtStorageSqlite::TABLE_CODEBOX_INSERT, -1, &p_stmt, nullptr) != SQLITE_OK)
-    {
+    if (sqlite3_prepare_v2(pDb, CtStorageSqlite::TABLE_CODEBOX_INSERT, -1, &p_stmt, nullptr) != SQLITE_OK) {
         spdlog::error("{}: {}", CtStorageSqlite::ERR_SQLITE_PREPV2, sqlite3_errmsg(pDb));
         retVal = false;
     }
-    else
-    {
+    else {
         const std::string codebox_txt = get_text_content();
         sqlite3_bind_int64(p_stmt, 1, node_id);
         sqlite3_bind_int64(p_stmt, 2, _charOffset+offset_adjustment);
@@ -237,8 +226,7 @@ bool CtCodebox::to_sqlite(sqlite3* pDb, const gint64 node_id, const int offset_a
         sqlite3_bind_int64(p_stmt, 8, _widthInPixels);
         sqlite3_bind_int64(p_stmt, 9, _highlightBrackets);
         sqlite3_bind_int64(p_stmt, 10, _showLineNumbers);
-        if (sqlite3_step(p_stmt) != SQLITE_DONE)
-        {
+        if (sqlite3_step(p_stmt) != SQLITE_DONE) {
             spdlog::error("{}: {}", CtStorageSqlite::ERR_SQLITE_STEP, sqlite3_errmsg(pDb));
             retVal = false;
         }
@@ -260,7 +248,9 @@ void CtCodebox::set_show_line_numbers(const bool showLineNumbers)
 
 void CtCodebox::set_width_height(int newWidth, int newHeight)
 {
-    if (newWidth) _frameWidth = newWidth;
+    if (newWidth) {
+        _frameWidth = newWidth;
+    }
     if (newHeight) {
         _frameHeight = newHeight;
         if (!_pCtMainWin->get_ct_config()->codeboxAutoResize) {
@@ -270,7 +260,7 @@ void CtCodebox::set_width_height(int newWidth, int newHeight)
                 _scrolledwindow.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
         }
     }
-    apply_width_height(_ctTextview.get_allocation().get_width());
+    apply_width_height(_pCtMainWin->get_text_view().get_allocation().get_width());
 }
 
 void CtCodebox::set_highlight_brackets(const bool highlightBrackets)
@@ -281,8 +271,7 @@ void CtCodebox::set_highlight_brackets(const bool highlightBrackets)
 
 void CtCodebox::apply_cursor_pos(const int cursorPos)
 {
-    if (cursorPos > 0)
-    {
+    if (cursorPos > 0) {
         _rTextBuffer->place_cursor(_rTextBuffer->get_iter_at_offset(cursorPos));
     }
 }
@@ -290,30 +279,25 @@ void CtCodebox::apply_cursor_pos(const int cursorPos)
 // Catches CodeBox Key Presses
 bool CtCodebox::_on_key_press_event(GdkEventKey* event)
 {
-    _key_down = true;
     if (not _pCtMainWin->user_active())
         return false;
-    if (event->state & Gdk::CONTROL_MASK)
-    {
+    if (event->state & Gdk::CONTROL_MASK) {
         _pCtMainWin->get_ct_actions()->curr_codebox_anchor = this;
-        if (event->keyval == GDK_KEY_period)
-        {
+        if (event->keyval == GDK_KEY_period) {
             if (event->state & Gdk::MOD1_MASK)
                 _pCtMainWin->get_ct_actions()->codebox_decrease_width();
             else
                 _pCtMainWin->get_ct_actions()->codebox_increase_width();
             return true;
         }
-        else if (event->keyval == GDK_KEY_comma)
-        {
+        else if (event->keyval == GDK_KEY_comma) {
             if (event->state & Gdk::MOD1_MASK)
                 _pCtMainWin->get_ct_actions()->codebox_decrease_height();
             else
                 _pCtMainWin->get_ct_actions()->codebox_increase_height();
             return true;
         }
-        else if (event->keyval == GDK_KEY_space)
-        {
+        else if (event->keyval == GDK_KEY_space) {
             Gtk::TextIter text_iter = _pCtMainWin->get_text_view().get_buffer()->get_iter_at_child_anchor(getTextChildAnchor());
             text_iter.forward_char();
             _pCtMainWin->get_text_view().get_buffer()->place_cursor(text_iter);
@@ -330,23 +314,18 @@ bool CtCodebox::_on_key_press_event(GdkEventKey* event)
         }
     }
     //std::cout << "keyval " << event->keyval << std::endl;
-    if (event->keyval == GDK_KEY_Tab or event->keyval == GDK_KEY_ISO_Left_Tab)
-    {
+    if (event->keyval == GDK_KEY_Tab or event->keyval == GDK_KEY_ISO_Left_Tab) {
         auto text_buffer = _ctTextview.get_buffer();
-        if (not text_buffer->get_has_selection())
-        {
+        if (not text_buffer->get_has_selection()) {
             Gtk::TextIter iter_insert = text_buffer->get_insert()->get_iter();
             CtListInfo list_info = CtList(_pCtMainWin, text_buffer).get_paragraph_list_info(iter_insert);
             bool backward = event->state & Gdk::SHIFT_MASK;
-            if (list_info)
-            {
-                if (backward and list_info.level)
-                {
+            if (list_info) {
+                if (backward and list_info.level) {
                     _ctTextview.list_change_level(iter_insert, list_info, false);
                     return true;
                 }
-                else if (not backward)
-                {
+                else if (not backward) {
                     _ctTextview.list_change_level(iter_insert, list_info, true);
                     return true;
                 }
