@@ -34,6 +34,7 @@ const fs::path CtConfig::LangFilename{"lang"};
 const fs::path CtConfig::LogFilename{"log"};
 const fs::path CtConfig::ConfigLanguageSpecsDirname{"language-specs"};
 const fs::path CtConfig::ConfigStylesDirname{"styles"};
+const fs::path CtConfig::ConfigIconsDirname{"icons"};
 const fs::path CtConfig::UserStyleTemplate{"user-style.xml"};
 
 CtConfig::CtConfig()
@@ -196,6 +197,8 @@ void CtConfig::_populate_keyfile_from_data()
         ++i;
     }
     _uKeyFile->set_boolean(_currentGroup, "toolbar_visible", toolbarVisible);
+    _uKeyFile->set_boolean(_currentGroup, "statusbar_visible", statusbarVisible);
+    _uKeyFile->set_boolean(_currentGroup, "tree_lines_visible", treeLinesVisible);
     _uKeyFile->set_boolean(_currentGroup, "win_is_maximized", winIsMaximised);
     _uKeyFile->set_integer(_currentGroup, "win_position_x", winRect[0]);
     _uKeyFile->set_integer(_currentGroup, "win_position_y", winRect[1]);
@@ -203,6 +206,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_integer(_currentGroup, "win_size_h", winRect[3]);
     _uKeyFile->set_integer(_currentGroup, "hpaned_pos", hpanedPos);
     _uKeyFile->set_boolean(_currentGroup, "tree_visible", treeVisible);
+    _uKeyFile->set_boolean(_currentGroup, "menubar_visible", menubarVisible);
     _uKeyFile->set_string(_currentGroup, "pick_dir_import", pickDirImport);
     _uKeyFile->set_string(_currentGroup, "pick_dir_export", pickDirExport);
     _uKeyFile->set_string(_currentGroup, "pick_dir_file", pickDirFile);
@@ -210,6 +214,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "pick_dir_csv", pickDirCsv);
     _uKeyFile->set_string(_currentGroup, "pick_dir_cbox", pickDirCbox);
     _uKeyFile->set_string(_currentGroup, "link_type", linkType);
+    _uKeyFile->set_boolean(_currentGroup, "menubar_in_titlebar", menubarInTitlebar);
     _uKeyFile->set_boolean(_currentGroup, "show_node_name_header", showNodeNameHeader);
     _uKeyFile->set_integer(_currentGroup, "nodes_on_node_name_header", nodesOnNodeNameHeader);
     _uKeyFile->set_integer(_currentGroup, "toolbar_icon_size", toolbarIconSize);
@@ -313,6 +318,8 @@ void CtConfig::_populate_keyfile_from_data()
     _currentGroup = "colors";
     _uKeyFile->set_string(_currentGroup, "tt_def_fg", ttDefFg);
     _uKeyFile->set_string(_currentGroup, "tt_def_bg", ttDefBg);
+    _uKeyFile->set_string(_currentGroup, "tt_sel_fg", ttSelFg);
+    _uKeyFile->set_string(_currentGroup, "tt_sel_bg", ttSelBg);
     _uKeyFile->set_string(_currentGroup, "scalable_h1", scalableH1.serialise());
     _uKeyFile->set_string(_currentGroup, "scalable_h2", scalableH2.serialise());
     _uKeyFile->set_string(_currentGroup, "scalable_h3", scalableH3.serialise());
@@ -324,7 +331,6 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "monospace_bg", monospaceBg);
     _uKeyFile->set_boolean(_currentGroup, "ms_dedic_font", msDedicatedFont);
     _uKeyFile->set_string(_currentGroup, "monospace_font", monospaceFont);
-    _uKeyFile->set_string(_currentGroup, "color_palette", colorPalette);
     _uKeyFile->set_string(_currentGroup, "col_link_webs", colLinkWebs);
     _uKeyFile->set_string(_currentGroup, "col_link_node", colLinkNode);
     _uKeyFile->set_string(_currentGroup, "col_link_file", colLinkFile);
@@ -422,6 +428,8 @@ void CtConfig::_populate_data_from_keyfile()
         }
     }
     _populate_bool_from_keyfile("toolbar_visible", &toolbarVisible);
+    _populate_bool_from_keyfile("statusbar_visible", &statusbarVisible);
+    _populate_bool_from_keyfile("tree_lines_visible", &treeLinesVisible);
     _populate_bool_from_keyfile("win_is_maximized", &winIsMaximised);
     _populate_int_from_keyfile("win_position_x", &winRect[0]);
     _populate_int_from_keyfile("win_position_y", &winRect[1]);
@@ -429,6 +437,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_int_from_keyfile("win_size_h", &winRect[3]);
     _populate_int_from_keyfile("hpaned_pos", &hpanedPos);
     _populate_bool_from_keyfile("tree_visible", &treeVisible);
+    _populate_bool_from_keyfile("menubar_visible", &menubarVisible);
     if (savedFromPyGtk) {
         CtRecentDocRestore recentDocRestore;
         if (_populate_string_from_keyfile("node_path", &recentDocRestore.node_path)) {
@@ -450,6 +459,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("pick_dir_cbox", &pickDirCbox);
     pickDirCbox = fs_canonicalize_filename(pickDirCbox);
     _populate_string_from_keyfile("link_type", &linkType);
+    _populate_bool_from_keyfile("menubar_in_titlebar", &menubarInTitlebar);
     _populate_bool_from_keyfile("show_node_name_header", &showNodeNameHeader);
     _populate_int_from_keyfile("nodes_on_node_name_header", &nodesOnNodeNameHeader);
     _populate_int_from_keyfile("toolbar_icon_size", &toolbarIconSize);
@@ -602,6 +612,8 @@ void CtConfig::_populate_data_from_keyfile()
     _currentGroup = "colors";
     _populate_string_from_keyfile("tt_def_fg", &ttDefFg);
     _populate_string_from_keyfile("tt_def_bg", &ttDefBg);
+    _populate_string_from_keyfile("tt_sel_fg", &ttSelFg);
+    _populate_string_from_keyfile("tt_sel_bg", &ttSelBg);
     std::string tmpScalable;
     _populate_string_from_keyfile("scalable_h1", &tmpScalable);
     scalableH1.deserialise(tmpScalable.c_str(), CtConst::SCALABLE_H1_DEFAULT);
@@ -621,7 +633,6 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("monospace_bg", &monospaceBg);
     _populate_bool_from_keyfile("ms_dedic_font", &msDedicatedFont);
     _populate_string_from_keyfile("monospace_font", &monospaceFont);
-    _populate_string_from_keyfile("color_palette", &colorPalette);
     _populate_string_from_keyfile("col_link_webs", &colLinkWebs);
     _populate_string_from_keyfile("col_link_node", &colLinkNode);
     _populate_string_from_keyfile("col_link_file", &colLinkFile);
