@@ -42,6 +42,7 @@ public:
     static const fs::path LogFilename;
     static const fs::path ConfigLanguageSpecsDirname;
     static const fs::path ConfigStylesDirname;
+    static const fs::path ConfigIconsDirname;
     static const fs::path UserStyleTemplate;
 
     bool getInitLoadFromFileOk() { return _initLoadFromFileOk; }
@@ -54,10 +55,13 @@ public:
     // [state]
     CtRecentDocsRestore                         recentDocsRestore;
     bool                                        toolbarVisible{true};
+    bool                                        statusbarVisible{true};
+    bool                                        treeLinesVisible{false};
     bool                                        winIsMaximised{false};
     int                                         winRect[4]{10, 10, 963, 630};
     int                                         hpanedPos{170};
     bool                                        treeVisible{true};
+    bool                                        menubarVisible{true};
     CtRecentDocsFilepaths                       recentDocsFilepaths;
     std::string                                 pickDirImport;
     std::string                                 pickDirExport;
@@ -66,6 +70,7 @@ public:
     std::string                                 pickDirCsv;
     std::string                                 pickDirCbox;
     std::string                                 linkType{CtConst::LINK_TYPE_WEBS};
+    bool                                        menubarInTitlebar{false};
     bool                                        showNodeNameHeader{true};
     int                                         nodesOnNodeNameHeader{3};
     int                                         toolbarIconSize{1};
@@ -134,11 +139,11 @@ public:
     bool                                        weblinkCustomOn{false};
     bool                                        filelinkCustomOn{false};
     bool                                        folderlinkCustomOn{false};
-#if defined(_WIN32) || defined(_WIN64)
+#if defined(_WIN32)
     std::string                                 weblinkCustomAct{"explorer %s &"};
     std::string                                 filelinkCustomAct{"explorer %s &"};
     std::string                                 folderlinkCustomAct{"explorer %s &"};
-#elif __APPLE__
+#elif defined(__APPLE__)
     std::string                                 weblinkCustomAct{"open %s &"};
     std::string                                 filelinkCustomAct{"open %s &"};
     std::string                                 folderlinkCustomAct{"open %s &"};
@@ -162,19 +167,21 @@ public:
     int                                         tableColWidthDefault{60};
 
     // [fonts]
-    Glib::ustring                               rtFont{"Sans 9"};
-    Glib::ustring                               ptFont{"Sans 9"};
-    Glib::ustring                               treeFont{"Sans 8"};
-    Glib::ustring                               codeFont{"Monospace 9"};
+    Glib::ustring                               rtFont{CtConst::FONT_RT_DEFAULT};
+    Glib::ustring                               ptFont{CtConst::FONT_PT_DEFAULT};
+    Glib::ustring                               treeFont{CtConst::FONT_TREE_DEFAULT};
+    Glib::ustring                               codeFont{CtConst::FONT_CODE_DEFAULT};
     Glib::ustring                               fallbackFontFamily{"Sans"};
 
     // [colors]
     std::string                                 ttDefFg{CtConst::TREE_TEXT_LIGHT_FG};
     std::string                                 ttDefBg{CtConst::TREE_TEXT_LIGHT_BG};
+    std::string                                 ttSelFg{CtConst::TREE_TEXT_LIGHT_BG};
+    std::string                                 ttSelBg{CtConst::TREE_TEXT_SEL_BG};
     std::string                                 monospaceFg{CtConst::DEFAULT_MONOSPACE_FG};
     std::string                                 monospaceBg{CtConst::DEFAULT_MONOSPACE_BG};
     bool                                        msDedicatedFont{false};
-    Glib::ustring                               monospaceFont{"Monospace 9"};
+    Glib::ustring                               monospaceFont{CtConst::FONT_MS_DEFAULT};
     CtScalableTag                               scalableH1{CtConst::SCALABLE_H1_DEFAULT};
     CtScalableTag                               scalableH2{CtConst::SCALABLE_H2_DEFAULT};
     CtScalableTag                               scalableH3{CtConst::SCALABLE_H3_DEFAULT};
@@ -182,10 +189,6 @@ public:
     CtScalableTag                               scalableH5{CtConst::SCALABLE_H5_DEFAULT};
     CtScalableTag                               scalableH6{CtConst::SCALABLE_H6_DEFAULT};
     CtScalableTag                               scalableSmall{CtConst::SCALABLE_SMALL_DEFAULT};
-    std::string                                 colorPalette{"#000000:#ffffff:#7f7f7f:#ff0000:#a020f0:"
-                                                             "#0000ff:#add8e6:#00ff00:#ffff00:#ffa500:"
-                                                             "#e6e6fa:#a52a2a:#8b6914:#1e90ff:#ffc0cb:"
-                                                             "#90ee90:#1a1a1a:#4d4d4d:#bfbfbf:#e5e5e5"};
     std::string                                 colLinkWebs{CtConst::COLOR_48_LINK_WEBS};
     std::string                                 colLinkNode{CtConst::COLOR_48_LINK_NODE};
     std::string                                 colLinkFile{CtConst::COLOR_48_LINK_FILE};
