@@ -29,8 +29,7 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
                                      const std::string& title,
                                      CtSearchOptions& s_options,
                                      bool replace_on,
-                                     bool multiple_nodes,
-                                     bool pattern_required)
+                                     bool multiple_nodes)
 {
     Gtk::Dialog dialog{title,
                        *pParentWin,
@@ -43,16 +42,14 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
     dialog.set_default_size(400, -1);
 
     Gtk::Entry search_entry{};
-    search_entry.set_text(s_options.search_replace_dict_find);
+    search_entry.set_text(s_options.str_find);
 
     auto button_ok = dialog.get_widget_for_response(Gtk::RESPONSE_ACCEPT);
-    if (pattern_required) {
-        button_ok->set_sensitive(s_options.search_replace_dict_find.length() != 0);
-        search_entry.signal_changed().connect([&button_ok, &search_entry](){
-            button_ok->set_sensitive(search_entry.get_text().length() != 0);
-        });
-    }
-    auto search_frame = Gtk::Frame(std::string("<b>")+_("Search for")+"</b>");
+    button_ok->set_sensitive(s_options.str_find.length() != 0);
+    search_entry.signal_changed().connect([&button_ok, &search_entry](){
+        button_ok->set_sensitive(search_entry.get_text().length() != 0);
+    });
+    auto search_frame = Gtk::Frame{std::string("<b>")+_("Search for")+"</b>"};
     dynamic_cast<Gtk::Label*>(search_frame.get_label_widget())->set_use_markup(true);
     search_frame.set_shadow_type(Gtk::SHADOW_NONE);
     search_frame.add(search_entry);
@@ -61,7 +58,7 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
     Gtk::Entry* replace_entry{nullptr};
     if (replace_on) {
         replace_entry = Gtk::manage(new Gtk::Entry{});
-        replace_entry->set_text(s_options.search_replace_dict_replace);
+        replace_entry->set_text(s_options.str_replace);
         replace_frame = Gtk::manage(new Gtk::Frame{std::string("<b>")+_("Replace with")+"</b>"});
         dynamic_cast<Gtk::Label*>(replace_frame->get_label_widget())->set_use_markup(true);
         replace_frame->set_shadow_type(Gtk::SHADOW_NONE);
@@ -78,26 +75,26 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
     three_hbox.set_homogeneous(true);
     Gtk::Box three_vbox{Gtk::ORIENTATION_VERTICAL};
     Gtk::CheckButton match_case_checkbutton{_("Match Case")};
-    match_case_checkbutton.set_active(s_options.search_replace_dict_match_case);
+    match_case_checkbutton.set_active(s_options.match_case);
     Gtk::CheckButton reg_exp_checkbutton{_("Regular Expression")};
-    reg_exp_checkbutton.set_active(s_options.search_replace_dict_reg_exp);
+    reg_exp_checkbutton.set_active(s_options.reg_exp);
     Gtk::CheckButton whole_word_checkbutton{_("Whole Word")};
-    whole_word_checkbutton.set_active(s_options.search_replace_dict_whole_word);
+    whole_word_checkbutton.set_active(s_options.whole_word);
     Gtk::CheckButton start_word_checkbutton{_("Start Word")};
-    start_word_checkbutton.set_active(s_options.search_replace_dict_start_word);
+    start_word_checkbutton.set_active(s_options.start_word);
     Gtk::RadioButton fw_radiobutton{_("Forward")};
-    fw_radiobutton.set_active(s_options.search_replace_dict_fw);
+    fw_radiobutton.set_active(s_options.direction_fw);
     Gtk::RadioButton bw_radiobutton{_("Backward")};
     bw_radiobutton.join_group(fw_radiobutton);
-    bw_radiobutton.set_active(!s_options.search_replace_dict_fw);
+    bw_radiobutton.set_active(!s_options.direction_fw);
     Gtk::RadioButton all_radiobutton{_("All, List Matches")};
-    all_radiobutton.set_active(s_options.search_replace_dict_a_ff_fa == 0);
+    all_radiobutton.set_active(s_options.all_firstsel_firstall == 0);
     Gtk::RadioButton first_from_radiobutton{_("First From Selection")};
     first_from_radiobutton.join_group(all_radiobutton);
-    first_from_radiobutton.set_active(s_options.search_replace_dict_a_ff_fa == 1);
+    first_from_radiobutton.set_active(s_options.all_firstsel_firstall == 1);
     Gtk::RadioButton first_all_radiobutton{_("First in All Range")};
     first_all_radiobutton.join_group(all_radiobutton);
-    first_all_radiobutton.set_active(s_options.search_replace_dict_a_ff_fa == 2);
+    first_all_radiobutton.set_active(s_options.all_firstsel_firstall == 2);
 
     Gtk::Frame* ts_frame{nullptr};
     Gtk::CheckButton* ts_node_created_after_checkbutton{nullptr};
@@ -177,8 +174,17 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
                        _("Node Modified Before"),
                        &s_options.ts_mod_before.time));
     }
+    Gtk::CheckButton node_content_checkbutton{_("Node Content")};
+    node_content_checkbutton.set_active(s_options.node_content);
+    Gtk::CheckButton node_name_n_tags_checkbutton{_("Node Name and Tags")};
+    node_name_n_tags_checkbutton.set_active(s_options.node_name_n_tags);
+    Gtk::Box hbox_node_content_name_n_tags{Gtk::ORIENTATION_HORIZONTAL, 3/*spacing*/};
+    hbox_node_content_name_n_tags.pack_start(node_content_checkbutton);
+    hbox_node_content_name_n_tags.pack_start(node_name_n_tags_checkbutton);
+    Gtk::CheckButton only_sel_n_subnodes_checkbutton{_("Only Selected Node and Subnodes")};
+    only_sel_n_subnodes_checkbutton.set_active(s_options.only_sel_n_subnodes);
     Gtk::CheckButton iter_dialog_checkbutton{_("Show Iterated Find/Replace Dialog")};
-    iter_dialog_checkbutton.set_active(s_options.search_replace_dict_idialog);
+    iter_dialog_checkbutton.set_active(s_options.iterative_dialog);
     four_1_hbox.pack_start(match_case_checkbutton);
     four_1_hbox.pack_start(reg_exp_checkbutton);
     four_2_hbox.pack_start(whole_word_checkbutton);
@@ -199,6 +205,8 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
     if (multiple_nodes) {
         opt_vbox.pack_start(*ts_frame);
         opt_vbox.pack_start(*Gtk::manage(new Gtk::HSeparator{}));
+        opt_vbox.pack_start(hbox_node_content_name_n_tags);
+        opt_vbox.pack_start(only_sel_n_subnodes_checkbutton);
     }
     opt_vbox.pack_start(iter_dialog_checkbutton);
     Gtk::Frame opt_frame{std::string("<b>")+_("Search options")+"</b>"};
@@ -224,27 +232,33 @@ std::string CtDialogs::dialog_search(Gtk::Window* pParentWin,
     };
     dialog.signal_key_press_event().connect(press_enter);
     search_entry.signal_key_press_event().connect(press_enter, false);
+    if (replace_on) {
+        replace_entry->signal_key_press_event().connect(press_enter, false);
+    }
 
     if (dialog.run() != Gtk::RESPONSE_ACCEPT) {
         return "";
     }
-    s_options.search_replace_dict_find = search_entry.get_text();
+    s_options.str_find = search_entry.get_text();
     if (replace_on)
-        s_options.search_replace_dict_replace = replace_entry->get_text();
-    s_options.search_replace_dict_match_case = match_case_checkbutton.get_active();
-    s_options.search_replace_dict_reg_exp = reg_exp_checkbutton.get_active();
-    s_options.search_replace_dict_whole_word = whole_word_checkbutton.get_active();
-    s_options.search_replace_dict_start_word = start_word_checkbutton.get_active();
-    s_options.search_replace_dict_fw = fw_radiobutton.get_active();
-    if (all_radiobutton.get_active())              s_options.search_replace_dict_a_ff_fa = 0;
-    else if (first_from_radiobutton.get_active())  s_options.search_replace_dict_a_ff_fa = 1;
-    else                                           s_options.search_replace_dict_a_ff_fa = 2;
+        s_options.str_replace = replace_entry->get_text();
+    s_options.match_case = match_case_checkbutton.get_active();
+    s_options.reg_exp = reg_exp_checkbutton.get_active();
+    s_options.whole_word = whole_word_checkbutton.get_active();
+    s_options.start_word = start_word_checkbutton.get_active();
+    s_options.direction_fw = fw_radiobutton.get_active();
+    if (all_radiobutton.get_active())              s_options.all_firstsel_firstall = 0;
+    else if (first_from_radiobutton.get_active())  s_options.all_firstsel_firstall = 1;
+    else                                           s_options.all_firstsel_firstall = 2;
     s_options.ts_cre_after.on = multiple_nodes ? ts_node_created_after_checkbutton->get_active() : false;
     s_options.ts_cre_before.on = multiple_nodes ? ts_node_created_before_checkbutton->get_active() : false;
     s_options.ts_mod_after.on = multiple_nodes ? ts_node_modified_after_checkbutton->get_active() : false;
     s_options.ts_mod_before.on = multiple_nodes ? ts_node_modified_before_checkbutton->get_active() : false;
-    s_options.search_replace_dict_idialog = iter_dialog_checkbutton.get_active();
-    return s_options.search_replace_dict_find;
+    s_options.node_content = node_content_checkbutton.get_active();
+    s_options.node_name_n_tags = node_name_n_tags_checkbutton.get_active();
+    s_options.only_sel_n_subnodes = only_sel_n_subnodes_checkbutton.get_active();
+    s_options.iterative_dialog = iter_dialog_checkbutton.get_active();
+    return s_options.str_find;
 }
 
 void CtDialogs::match_dialog(const Glib::ustring& title,
@@ -282,12 +296,12 @@ void CtDialogs::match_dialog(const Glib::ustring& title,
 
     auto select_found_line = [pTreeview, rModel, pCtMainWin](){
         Gtk::TreeIter list_iter = pTreeview->get_selection()->get_selected();
-        if (!list_iter) {
+        if (not list_iter) {
             return;
         }
         gint64 node_id = list_iter->get_value(rModel->columns.node_id);
         CtTreeIter tree_iter = pCtMainWin->get_tree_store().get_node_from_node_id(node_id);
-        if (!tree_iter) {
+        if (not tree_iter) {
             CtDialogs::error_dialog(str::format(_("The Link Refers to a Node that Does Not Exist Anymore (Id = %s)"), node_id),
                                     *pCtMainWin);
             rModel->erase(list_iter);
@@ -308,7 +322,7 @@ void CtDialogs::match_dialog(const Glib::ustring& title,
             gtk_main_iteration();
     };
 
-    if (!rModel->saved_path.empty()) {
+    if (not rModel->saved_path.empty()) {
         auto iter = rModel->get_iter(rModel->saved_path);
         if (iter) {
             pTreeview->set_cursor(rModel->get_path(iter));
@@ -339,7 +353,7 @@ void CtDialogs::match_dialog(const Glib::ustring& title,
 // Iterated Find/Replace Dialog
 void CtDialogs::iterated_find_dialog(CtMainWin* pCtMainWin, CtSearchState& s_state)
 {
-    if (!s_state.iteratedfinddialog) {
+    if (not s_state.iteratedfinddialog) {
         spdlog::debug("+iteratedfinddialog");
         auto pDialog = new Gtk::Dialog{_("Iterate Latest Find/Replace"),
                                        *pCtMainWin,
