@@ -1,7 +1,7 @@
 /*
  * ct_export2html.cc
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -30,7 +30,6 @@
 #include "ct_process.h"
 #include "ct_filesystem.h"
 
-
 CtExport2Html::CtExport2Html(CtMainWin* pCtMainWin)
  : _pCtMainWin(pCtMainWin)
 {
@@ -57,14 +56,14 @@ bool CtExport2Html::prepare_html_folder(fs::path dir_place, fs::path new_folder,
     g_mkdir_with_parents(_res_dir.c_str(), 0777);
 
     fs::path config_dir = fs::get_cherrytree_configdir();
-    fs::path styles_css_filepath = config_dir / "styles3.css";
+    fs::path styles_css_filepath = config_dir / "styles4.css";
     if (!fs::is_regular_file(styles_css_filepath))
     {
-        fs::path styles_css_original = fs::path(fs::get_cherrytree_datadir()) / fs::path("data") / "styles3.css";
+        fs::path styles_css_original = fs::path(fs::get_cherrytree_datadir()) / fs::path("data") / "styles4.css";
         fs::copy_file(styles_css_original, styles_css_filepath);
     }
-    fs::copy_file(styles_css_filepath, _res_dir / "styles3.css");
-    
+    fs::copy_file(styles_css_filepath, _res_dir / "styles4.css");
+
     fs::path styles_js_filepath = config_dir / "script3.js";
     if (!fs::is_regular_file(styles_js_filepath))
     {
@@ -201,7 +200,6 @@ void CtExport2Html::nodes_all_export_to_multiple_html(bool all_tree, const CtExp
     }
 }
 
-
 // Export All Nodes To Single HTML
 void CtExport2Html::nodes_all_export_to_single_html(bool all_tree, const CtExportOptions&)
 {
@@ -251,9 +249,9 @@ void CtExport2Html::nodes_all_export_to_single_html(bool all_tree, const CtExpor
         }
         else
             html_text += _html_get_from_code_buffer(tree_iter.get_node_text_buffer(), -1, -1, tree_iter.get_node_syntax_highlighting());
-         html_text += "</div>"; // div class='page'
-         rFileStream->write(html_text.c_str(), html_text.bytes());
-         html_text.clear();
+        html_text += "</div>"; // div class='page'
+        rFileStream->write(html_text.c_str(), html_text.bytes());
+        html_text.clear();
 
         for (auto& child: tree_iter->children())
             traverseFunc(_pCtMainWin->get_tree_store().to_ct_tree_iter(child), node_level + 1);
@@ -357,7 +355,7 @@ Glib::ustring CtExport2Html::_get_embfile_html(CtImageEmbFile* embfile, CtTreeIt
     fs::path embfile_name = std::to_string(tree_iter.get_node_id()) + "-" +  embfile->get_file_name().string();
     fs::path embfile_rel_path = "EmbeddedFiles" / embfile_name;
     Glib::ustring embfile_html = "<table style=\"" + embfile_align_text + "\"><tr><td><a href=\"" +
-            embfile_rel_path.string() + "\">Linked file: " + embfile->get_file_name().string() + " </a></td></tr></table>";
+            embfile_rel_path.string_unix() + "\">Linked file: " + embfile->get_file_name().string() + " </a></td></tr></table>";
 
     g_file_set_contents((embed_dir / embfile_name).c_str(), embfile->get_raw_blob().c_str(), (gssize)embfile->get_raw_blob().size(), nullptr);
 
@@ -375,12 +373,12 @@ Glib::ustring CtExport2Html::_get_image_html(CtImage* image, const fs::path& ima
     if (tree_iter)
     {
         image_name = std::to_string(tree_iter->get_node_id()) + "-" + std::to_string(images_count) + ".png";
-        image_rel_path = Glib::build_filename ("images", image_name);
+        image_rel_path = (fs::path{"images"} / image_name).string_unix();
     }
     else
     {
         image_name = std::to_string(images_count) + ".png";
-        image_rel_path = "file://" + (images_dir / image_name).string();
+        image_rel_path = "file://" + (images_dir / image_name).string_unix();
     }
 
     Glib::ustring image_html = "<img src=\"" + image_rel_path + "\" alt=\"" + image_rel_path + "\" />";
@@ -414,14 +412,14 @@ Glib::ustring CtExport2Html::_get_table_html(CtTable* table)
         for (auto cell: row) {
             Glib::ustring content = str::xml_escape(cell->get_text_content());
             if (content.empty()) content = " "; // Otherwise the table will render with squashed cells
-    
+
             if (first) {
                 table_html += "<th>" + content + "</th>";
             } else {
                 table_html += "<td>" + content + "</td>";
             }
         }
-        
+
         if (first) first = false;
         table_html += "</tr>";
     }
@@ -433,44 +431,42 @@ Glib::ustring CtExport2Html::_get_table_html(CtTable* table)
 Glib::ustring CtExport2Html::_html_get_from_code_buffer(const Glib::RefPtr<Gsv::Buffer>& code_buffer, int sel_start, int sel_end, const std::string& syntax_highlighting)
 {
     Gtk::TextIter curr_iter = sel_start >= 0 ? code_buffer->get_iter_at_offset(sel_start) : code_buffer->begin();
-    code_buffer->ensure_highlight(curr_iter, code_buffer->end());
+    Gtk::TextIter end_iter = sel_end >= 0 ? code_buffer->get_iter_at_offset(sel_end) : code_buffer->end();
+
     if (_pCtMainWin->get_ct_config()->usePandoc && CtPandoc::supports_syntax(syntax_highlighting)) {
         if (CtPandoc::has_pandoc()) {
-            Gtk::TextIter end_iter = sel_end >= 0 ? code_buffer->get_iter_at_offset(sel_end) : code_buffer->end();
             Glib::ustring      input_txt(curr_iter, end_iter);
             std::istringstream ibuff(input_txt);
             std::ostringstream html_out;
             CtPandoc::to_html(ibuff, html_out, syntax_highlighting);
             return html_out.str();
-        } else {
+        }
+        else {
             spdlog::warn("Exported content is eligible for processing by Pandoc but Pandoc executable could not be found");
         }
     }
-    
-    Glib::ustring html_text      = "";
+
+    _pCtMainWin->apply_syntax_highlighting(code_buffer, syntax_highlighting, false/*forceReApply*/);
+    code_buffer->ensure_highlight(curr_iter, end_iter);
+
+    Glib::ustring html_text;
     Glib::ustring former_tag_str = CtConst::COLOR_48_BLACK;
     bool span_opened = false;
-    for (;;)
-    {
+    for (;;) {
         auto curr_tags = curr_iter.get_tags();
-        if (curr_tags.size() > 0)
-        {
+        if (curr_tags.size() > 0) {
             Glib::ustring curr_tag_str = curr_tags[0]->property_foreground_gdk().get_value().to_string();
             int font_weight = curr_tags[0]->property_weight().get_value();
-            if (curr_tag_str == CtConst::COLOR_48_BLACK)
-            {
-                if (former_tag_str != curr_tag_str)
-                {
+            if (curr_tag_str == CtConst::COLOR_48_BLACK) {
+                if (former_tag_str != curr_tag_str) {
                     former_tag_str = curr_tag_str;
                     // end of tag
                     html_text += "</span>";
                     span_opened = false;
                 }
             }
-            else
-            {
-                if (former_tag_str != curr_tag_str)
-                {
+            else {
+                if (former_tag_str != curr_tag_str) {
                     former_tag_str = curr_tag_str;
                     if (span_opened) html_text += "</span>";
                     // start of tag
@@ -481,23 +477,23 @@ Glib::ustring CtExport2Html::_html_get_from_code_buffer(const Glib::RefPtr<Gsv::
                 }
             }
         }
-        else if (span_opened)
-        {
+        else if (span_opened) {
             span_opened = false;
             former_tag_str = CtConst::COLOR_48_BLACK;
             html_text += "</span>";
         }
         Glib::ustring sym = str::xml_escape(Glib::ustring(1, curr_iter.get_char()));
-        html_text += str::replace(sym, " ", "&nbsp;");
-        if (!curr_iter.forward_char() || (sel_end >= 0 && curr_iter.get_offset() > sel_end))
-        {
+        //html_text += str::replace(sym, " ", "&nbsp;");
+        // let's try and use <pre></pre> instead of '&nbsp;' to preserve the spaces
+        html_text += sym;
+        if (!curr_iter.forward_char() || (sel_end >= 0 && curr_iter.get_offset() > sel_end)) {
             if (span_opened) html_text += "</span>";
             break;
         }
     }
 
     html_text = str::replace(html_text, CtConst::CHAR_NEWLINE, "<br />");
-    return "<div class=\"codebox\">" + html_text + "</div>";
+    return "<pre>" + html_text + "</pre>";
 }
 
 // Given a treestore iter returns the HTML rich text
@@ -534,126 +530,123 @@ Glib::ustring CtExport2Html::_html_process_slot(int start_offset, int end_offset
 
     curr_html_text = str::replace(curr_html_text, "<br/><p ", "<p ");
     curr_html_text = str::replace(curr_html_text, "</p><br/>", "</p>");
-    for (auto header: {CtConst::TAG_PROP_VAL_H1, CtConst::TAG_PROP_VAL_H2, CtConst::TAG_PROP_VAL_H3})
-        curr_html_text = str::replace(curr_html_text, ("</" + Glib::ustring(header) + "><" + Glib::ustring(header) + " >").c_str(), "");
-
+    for (auto header : {CtConst::TAG_PROP_VAL_H1, CtConst::TAG_PROP_VAL_H2, CtConst::TAG_PROP_VAL_H3,
+                        CtConst::TAG_PROP_VAL_H4, CtConst::TAG_PROP_VAL_H5, CtConst::TAG_PROP_VAL_H6}) {
+        curr_html_text = str::replace(curr_html_text, ("</" + Glib::ustring{header} + "><" + Glib::ustring{header} + " >").c_str(), "");
+    }
     return curr_html_text;
 }
 
 // Adds a slice to the HTML Text
-Glib::ustring CtExport2Html::_html_text_serialize(Gtk::TextIter start_iter, Gtk::TextIter end_iter, const CtCurrAttributesMap& curr_attributes)
+Glib::ustring CtExport2Html::_html_text_serialize(Gtk::TextIter start_iter,
+                                                  Gtk::TextIter end_iter,
+                                                  const CtCurrAttributesMap& curr_attributes)
 {
     Glib::ustring inner_text = str::xml_escape(start_iter.get_text(end_iter));
-    if (inner_text == "") return "";
+    if (inner_text.empty()) return inner_text;
     inner_text = str::replace(inner_text, CtConst::CHAR_NEWLINE, "<br />");
 
-    Glib::ustring html_attrs = "";
-    bool superscript_active = false;
-    bool subscript_active = false;
-    bool monospace_active = false;
-    bool bold_active = false;
-    bool italic_active = false;
-    for (auto tag_property: CtConst::TAG_PROPERTIES)
-    {
-        if (curr_attributes.at(tag_property) == "")
+    Glib::ustring html_attrs;
+    bool superscript_active{false};
+    bool subscript_active{false};
+    bool monospace_active{false};
+    bool bold_active{false};
+    bool italic_active{false};
+    Glib::ustring hN_active;
+    for (auto tag_property : CtConst::TAG_PROPERTIES) {
+        if (curr_attributes.at(tag_property).empty()) {
             continue;
+        }
         Glib::ustring property_value = curr_attributes.at(tag_property);
-        if (tag_property == CtConst::TAG_WEIGHT)
-        {
+        if (tag_property == CtConst::TAG_WEIGHT) {
             // font-weight:bolder
             // tag_property = "font-weight"
             // property_value = "bolder"
             bold_active = true;
             continue;
         }
-        else if (tag_property == CtConst::TAG_FOREGROUND)
-        {
+        else if (tag_property == CtConst::TAG_FOREGROUND) {
             // color:#FFFF00
             tag_property = "color";
             Glib::ustring color_no_white = CtRgbUtil::rgb_to_no_white(property_value);
             property_value = CtRgbUtil::get_rgb24str_from_str_any(color_no_white);
         }
-        else if (tag_property == CtConst::TAG_BACKGROUND)
-        {
+        else if (tag_property == CtConst::TAG_BACKGROUND) {
             // background-color:#FFFF00
             tag_property = "background-color";
             property_value = CtRgbUtil::get_rgb24str_from_str_any(property_value);
         }
-        else if (tag_property == CtConst::TAG_STYLE)
-        {
+        else if (tag_property == CtConst::TAG_STYLE) {
             // font-style:italic
             // tag_property = "font-style"
             // property_value = cons.TAG_PROP_ITALIC
             italic_active = true;
             continue;
         }
-        else if (tag_property == CtConst::TAG_UNDERLINE)
-        {
+        else if (tag_property == CtConst::TAG_UNDERLINE) {
             // text-decoration:underline
             tag_property = "text-decoration";
             property_value = CtConst::TAG_UNDERLINE;
         }
-        else if (tag_property == CtConst::TAG_STRIKETHROUGH)
-        {
+        else if (tag_property == CtConst::TAG_STRIKETHROUGH) {
             // text-decoration:line-through
             tag_property = "text-decoration";
             property_value = "line-through";
         }
-        else if (tag_property == CtConst::TAG_SCALE)
-        {
-            if (property_value == CtConst::TAG_PROP_VAL_SUP)
-            {
+        else if (tag_property == CtConst::TAG_SCALE) {
+            if (property_value == CtConst::TAG_PROP_VAL_SUP) {
                 superscript_active = true;
                 continue;
             }
-            else if (property_value == CtConst::TAG_PROP_VAL_SUB)
-            {
+            else if (property_value == CtConst::TAG_PROP_VAL_SUB) {
                 subscript_active = true;
                 continue;
             }
-            else
-            {
+            else {
                 // font-size:xx-large/x-large/x-small
                 tag_property = "font-size";
-                if (property_value == CtConst::TAG_PROP_VAL_SMALL) property_value = "x-small";
-                else if (property_value == CtConst::TAG_PROP_VAL_H1) property_value = "xx-large";
-                else if (property_value == CtConst::TAG_PROP_VAL_H2) property_value = "x-large";
-                else if (property_value == CtConst::TAG_PROP_VAL_H3) property_value = "large";
+                if (property_value == CtConst::TAG_PROP_VAL_SMALL) {
+                    property_value = "x-small";
+                }
+                else if (property_value == CtConst::TAG_PROP_VAL_H1 or
+                         property_value == CtConst::TAG_PROP_VAL_H2 or
+                         property_value == CtConst::TAG_PROP_VAL_H3 or
+                         property_value == CtConst::TAG_PROP_VAL_H4 or
+                         property_value == CtConst::TAG_PROP_VAL_H5 or
+                         property_value == CtConst::TAG_PROP_VAL_H6)
+                {
+                    // TODO apply user defined scalable tag properies
+                    hN_active = property_value;
+                }
             }
         }
-        else if (tag_property == CtConst::TAG_FAMILY)
-        {
+        else if (tag_property == CtConst::TAG_FAMILY) {
             monospace_active = true;
             continue;
         }
-        else if (tag_property == CtConst::TAG_JUSTIFICATION)
-        {
+        else if (tag_property == CtConst::TAG_JUSTIFICATION) {
             // text-align:center/left/right
             // tag_property = "text-align"
             continue;
         }
-        else if (tag_property == CtConst::TAG_LINK)
-        {
+        else if (tag_property == CtConst::TAG_LINK) {
             // <a href="http://www.example.com/">link-text goes here</a>
             Glib::ustring href = _get_href_from_link_prop_val(property_value);
-            if (href == "")
+            if (href.empty()) {
                 continue;
+            }
             Glib::ustring html_text = "<a href=\"" + href + "\">" + inner_text + "</a>";
             return html_text;
         }
-        html_attrs += Glib::ustring(tag_property.data()) + ":" + property_value + ";";
+        html_attrs += Glib::ustring{tag_property.data()} + ":" + property_value + ";";
     }
     Glib::ustring tagged_text;
-    if (html_attrs == "" || inner_text == "<br />")
+    if (html_attrs.empty() || inner_text == "<br />") {
         tagged_text = inner_text;
-    else
-    {
-        if (html_attrs.find("xx-large") != Glib::ustring::npos)
-            tagged_text = "<h1>" + inner_text + "</h1>";
-        else if (html_attrs.find("x-large") != Glib::ustring::npos)
-            tagged_text = "<h2>" + inner_text + "</h2>";
-        else if (html_attrs.find("large") != Glib::ustring::npos)
-            tagged_text = "<h3>" + inner_text + "</h3>";
+    }
+    else {
+        if (not hN_active.empty())
+            tagged_text = Glib::ustring{"<"} + hN_active + ">" + inner_text + Glib::ustring{"</"} + hN_active + ">";
         else if (html_attrs.find("x-small") != Glib::ustring::npos)
             tagged_text = "<small>" + inner_text + "</small>";
         else
@@ -678,9 +671,9 @@ std::string CtExport2Html::_get_href_from_link_prop_val(Glib::ustring link_prop_
     if (link_entry.type == CtConst::LINK_TYPE_WEBS)
         href = link_entry.webs;
     else if (link_entry.type == CtConst::LINK_TYPE_FILE)
-        href = "file://" + _link_process_filepath(link_entry.file, _pCtMainWin->get_ct_storage()->get_file_path().parent_path().string());
+        href = "file://" + link_process_filepath(link_entry.file, _pCtMainWin->get_ct_storage()->get_file_path().parent_path().string(), true/*forHtml*/);
     else if (link_entry.type == CtConst::LINK_TYPE_FOLD)
-        href = "file://" + _link_process_folderpath(link_entry.fold, _pCtMainWin->get_ct_storage()->get_file_path().parent_path().string());
+        href = "file://" + link_process_folderpath(link_entry.fold, _pCtMainWin->get_ct_storage()->get_file_path().parent_path().string(), true/*forHtml*/);
     else if (link_entry.type == CtConst::LINK_TYPE_NODE)
     {
         CtTreeIter node = _pCtMainWin->get_tree_store().get_node_from_node_id(link_entry.node_id);
@@ -694,22 +687,22 @@ std::string CtExport2Html::_get_href_from_link_prop_val(Glib::ustring link_prop_
     return href;
 }
 
-std::string CtExport2Html::_link_process_filepath(const std::string& filepath_raw, const std::string& relative_to)
+std::string CtExport2Html::link_process_filepath(const std::string& filepath_raw, const std::string& relative_to, const bool forHtml)
 {
     fs::path filepath = filepath_raw;
     fs::path abs_filepath = fs::canonical(filepath, relative_to);
     if (!fs::is_regular_file(filepath) && fs::is_regular_file(abs_filepath))
         filepath = abs_filepath;
-    return filepath.native();
+    return forHtml ? filepath.string_unix() : filepath.string();
 }
 
-std::string CtExport2Html::_link_process_folderpath(const std::string& folderpath_raw, const std::string& relative_to)
+std::string CtExport2Html::link_process_folderpath(const std::string& folderpath_raw, const std::string& relative_to, const bool forHtml)
 {
     fs::path folderpath = folderpath_raw;
     fs::path abs_folderpath = fs::canonical(folderpath, relative_to);
     if (!fs::is_directory(folderpath) && fs::is_directory(abs_folderpath))
         folderpath = abs_folderpath;
-    return folderpath.native();
+    return forHtml ? folderpath.string_unix() : folderpath.string();
 }
 
 // Returns the style attribute(s) according to the alignment
@@ -737,14 +730,14 @@ std::unique_ptr<CtProcess> pandoc_process() {
 namespace CtPandoc {
 
 // Checks if the specified file is in the PATH environment variable
-bool in_path(const std::string& file) 
+bool in_path(const std::string& file)
 {
     g_autofree gchar* prog_name = g_find_program_in_path(file.c_str());
     return prog_name != nullptr;
 }
 
 
-bool has_pandoc() 
+bool has_pandoc()
 {
     return in_path("pandoc");
 }
