@@ -74,16 +74,17 @@ void register_exe_path_detect_if_portable(const char* exe_path)
 {
     _exePath = fs::canonical(exe_path);
     //printf("exePath: %s\n", _exePath.c_str());
-
 #ifdef _WIN32
     // e.g. cherrytree_0.99.9_win64_portable\mingw64\bin\cherrytree.exe
     //      cherrytree_0.99.9_win64_portable\config.cfg
     const fs::path portableConfigDir = _exePath.parent_path().parent_path().parent_path();
+#else // !_WIN32
+    const fs::path portableConfigDir = _exePath.parent_path() / "config";
+#endif // !_WIN32
     const fs::path portableConfigFile = portableConfigDir / CtConfig::ConfigFilename;
     if (is_regular_file(portableConfigFile)) {
         _portableConfigDir = portableConfigDir;
     }
-#endif // _WIN32
 }
 
 bool remove(const fs::path& path2rm)
@@ -180,7 +181,7 @@ std::list<fs::path> get_dir_entries(const path& dir)
 {
     Glib::Dir gdir(dir.string());
     std::list<fs::path> entries(gdir.begin(), gdir.end());
-    for (auto& entry: entries)
+    for (auto& entry : entries)
         entry = dir / entry;
     return entries;
 }
@@ -401,6 +402,11 @@ fs::path get_cherrytree_config_styles_dirpath()
     return get_cherrytree_configdir() / CtConfig::ConfigStylesDirname;
 }
 
+fs::path get_cherrytree_config_icons_dirpath()
+{
+    return get_cherrytree_configdir() / CtConfig::ConfigIconsDirname;
+}
+
 fs::path get_cherrytree_config_user_style_filepath(const unsigned num)
 {
     return fs::canonical(get_cherrytree_config_styles_dirpath() / ("user-style-" + std::to_string(num) + ".xml"));
