@@ -1,7 +1,7 @@
 /*
  * ct_imports.cc
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -29,7 +29,6 @@
 #include "ct_logging.h"
 #include <libxml2/libxml/SAX.h>
 #include <fstream>
-#include <sstream>
 
 namespace {
 
@@ -145,19 +144,16 @@ std::vector<std::pair<size_t, size_t>> CtImports::get_web_links_offsets_from_pla
     size_t max_start_offset = max_end_offset - 7;
     size_t start_offset = 0;
     unsigned lastCharBeforeURL = 0;
-    while (start_offset < max_start_offset)
-    {
-        if (str::startswith_any(plain_text.substr(start_offset), CtConst::WEB_LINK_STARTERS))
-        {
+    while (start_offset < max_start_offset) {
+        if (str::startswith_any(plain_text.substr(start_offset), CtConst::WEB_LINK_STARTERS)) {
             size_t end_offset = start_offset + 3;
             unsigned closingParenthesisChar = 0;
             if (lastCharBeforeURL == '(') closingParenthesisChar = ')';
             else if (lastCharBeforeURL == '[') closingParenthesisChar = ']';
-            else if (lastCharBeforeURL == '{') closingParenthesisChar = '}';
             while (end_offset < max_end_offset and
-                   plain_text[end_offset] != ' ' and
-                   plain_text[end_offset] != '\n' and
-                   plain_text[end_offset] != closingParenthesisChar) {
+                   not strchr(CtConst::URL_INVALID_CHARS, plain_text[end_offset]) and
+                   plain_text[end_offset] != closingParenthesisChar)
+            {
                 ++end_offset;
             }
             web_links.push_back(std::make_pair(start_offset, end_offset));
@@ -171,9 +167,9 @@ std::vector<std::pair<size_t, size_t>> CtImports::get_web_links_offsets_from_pla
     return web_links;
 }
 
-std::unique_ptr<ct_imported_node> CtImports::traverse_dir(const fs::path& dir, CtImporterInterface* importer)
+std::unique_ptr<CtImportedNode> CtImports::traverse_dir(const fs::path& dir, CtImporterInterface* importer)
 {
-    auto dir_node = std::make_unique<ct_imported_node>(dir, dir.filename().string());
+    auto dir_node = std::make_unique<CtImportedNode>(dir, dir.filename().string());
     for (const auto& dir_item: fs::get_dir_entries(dir))
     {
         if (fs::is_directory(dir_item))
@@ -194,8 +190,8 @@ std::unique_ptr<ct_imported_node> CtImports::traverse_dir(const fs::path& dir, C
     // 1. children with the same names, one with content and other as dir, join them
     // 2. dir contains  note with the same name, join them (from keepnote)
 
-    std::function<void(std::unique_ptr<ct_imported_node>&)> join_subdir_subnote;
-    join_subdir_subnote = [&](std::unique_ptr<ct_imported_node>& node) {
+    std::function<void(std::unique_ptr<CtImportedNode>&)> join_subdir_subnote;
+    join_subdir_subnote = [&](std::unique_ptr<CtImportedNode>& node) {
         for (auto iter1 = node->children.begin(); iter1 != node->children.end(); ++iter1)
         {
             if ((*iter1)->has_content() && (*iter1)->children.empty()) // node with content
@@ -219,8 +215,8 @@ std::unique_ptr<ct_imported_node> CtImports::traverse_dir(const fs::path& dir, C
             join_subdir_subnote(child);
     };
 
-    std::function<void(std::unique_ptr<ct_imported_node>&)> join_parent_dir_subnote;
-    join_parent_dir_subnote = [&](std::unique_ptr<ct_imported_node>& node) {
+    std::function<void(std::unique_ptr<CtImportedNode>&)> join_parent_dir_subnote;
+    join_parent_dir_subnote = [&](std::unique_ptr<CtImportedNode>& node) {
         if (!node->has_content())
         {
             for (auto iter = node->children.begin(); iter != node->children.end(); ++iter)
@@ -244,35 +240,29 @@ std::unique_ptr<ct_imported_node> CtImports::traverse_dir(const fs::path& dir, C
     return dir_node;
 }
 
-CtHtmlImport::CtHtmlImport(CtConfig* config) : _config(config)
+CtHtmlImport::CtHtmlImport(CtConfig* config) : _config{config}
 {
 }
 
-std::unique_ptr<ct_imported_node> CtHtmlImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtHtmlImport::import_file(const fs::path& file)
 {
-    if (file.extension() != ".html" && file.extension() != ".htm")
+    if (file.extension() != ".html" && file.extension() != ".htm") {
         return nullptr;
-
-    std::ifstream infile;
-    infile.exceptions(std::ios_base::failbit);
-    infile.open(file.string());
-    std::ostringstream ss;
-    ss << infile.rdbuf();
-
-    auto imported_node = std::make_unique<ct_imported_node>(file, file.stem().string());
-    CtHtml2Xml html2xml(_config);
+    }
+    std::string htmlStr = Glib::file_get_contents(file.string());
+    auto node = std::make_unique<CtImportedNode>(file, file.stem().string());
+    CtHtml2Xml html2xml{_config};
     html2xml.set_local_dir(file.parent_path().string());
-    html2xml.set_outter_xml_doc(imported_node->xml_content.get());
-    html2xml.feed(ss.str());
-
-    return imported_node;
+    html2xml.set_outter_xml_doc(node->xml_content.get());
+    html2xml.feed(htmlStr);
+    return node;
 }
 
-CtTomboyImport::CtTomboyImport(CtConfig* config) : _config(config)
+CtTomboyImport::CtTomboyImport(CtConfig* config) : _config{config}
 {
 }
 
-std::unique_ptr<ct_imported_node> CtTomboyImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtTomboyImport::import_file(const fs::path& file)
 {
     xmlpp::DomParser tomboy_doc;
     try { tomboy_doc.parse_file(file.string());}
@@ -309,8 +299,8 @@ std::unique_ptr<ct_imported_node> CtTomboyImport::import_file(const fs::path& fi
     if (xmlpp::Node* text_el = note_el->get_first_child("text"))
         if (xmlpp::Node* content_el = text_el->get_first_child("note-content"))
         {
-            auto parent_node = std::make_unique<ct_imported_node>(file, parent_name);
-            auto node = std::make_unique<ct_imported_node>(file, node_name);
+            auto parent_node = std::make_unique<CtImportedNode>(file, parent_name);
+            auto node = std::make_unique<CtImportedNode>(file, node_name);
 
             _current_node = node->xml_content->create_root_node("root")->add_child("slot");
             _curr_attributes.clear();
@@ -325,7 +315,7 @@ std::unique_ptr<ct_imported_node> CtTomboyImport::import_file(const fs::path& fi
     return nullptr;
 }
 
-void CtTomboyImport::_iterate_tomboy_note(xmlpp::Element* iter, std::unique_ptr<ct_imported_node>& node)
+void CtTomboyImport::_iterate_tomboy_note(xmlpp::Element* iter, std::unique_ptr<CtImportedNode>& node)
 {
     for (auto dom_iter: iter->get_children())
     {
@@ -407,13 +397,13 @@ xmlpp::Element* CtTomboyImport::_rich_text_serialize(const Glib::ustring& text_d
 
 CtZimImport::CtZimImport(CtConfig* config) : _zim_parser{std::make_unique<CtZimParser>(config)} {}
 
-std::unique_ptr<ct_imported_node> CtZimImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtZimImport::import_file(const fs::path& file)
 {
     if (file.extension() != ".txt") return nullptr;
 
     _ensure_notebook_file_in_dir(file.parent_path());
 
-    std::unique_ptr<ct_imported_node> node = std::make_unique<ct_imported_node>(file, file.stem().string());
+    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem().string());
 
     std::ifstream stream;
     stream.exceptions(std::ios::failbit);
@@ -447,31 +437,21 @@ void CtZimImport::_ensure_notebook_file_in_dir(const fs::path& dir)
 
 CtMDImport::~CtMDImport() = default;
 
-std::unique_ptr<ct_imported_node> CtPlainTextImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtPlainTextImport::import_file(const fs::path& file)
 {
-    if (!CtMiscUtil::mime_type_contains(file.string(), "text/"))
+    if (!CtMiscUtil::mime_type_contains(file.string(), "text/")) {
         return nullptr;
-
-    try
-    {
-        std::ifstream infile;
-        infile.exceptions(std::ios_base::failbit);
-        infile.open(file.string());
-        std::ostringstream data;
-        data << infile.rdbuf();
-        std::string converted = data.str();
-        const std::string codeset = CtStrUtil::get_encoding(converted.c_str(), converted.size());
-        if (CtStrUtil::is_codeset_not_utf8(codeset)) {
-            converted = Glib::convert_with_fallback(converted, "UTF-8", codeset);
-        }
-        std::unique_ptr<ct_imported_node> node = std::make_unique<ct_imported_node>(file, file.stem().string());
+    }
+    try {
+        std::string converted = Glib::file_get_contents(file.string());
+        CtStrUtil::convert_if_not_utf8(converted, true/*sanitise*/);
+        auto node = std::make_unique<CtImportedNode>(file, file.stem().string());
         node->xml_content->create_root_node("root")->add_child("slot")->add_child("rich_text")->add_child_text(converted);
         node->node_syntax = CtConst::PLAIN_TEXT_ID;
         return node;
     }
-    catch (std::exception& ex)
-    {
-        spdlog::error("CtPlainTextImport, what: , file: {}", ex.what(), file);
+    catch (std::exception& ex) {
+        spdlog::error("{}, what: {}, file: {}", __FUNCTION__, ex.what(), file);
     }
     return nullptr;
 }
@@ -480,7 +460,7 @@ CtMDImport::CtMDImport(CtConfig* config) : _parser{std::make_unique<CtMDParser>(
 {
 }
 
-std::unique_ptr<ct_imported_node> CtMDImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtMDImport::import_file(const fs::path& file)
 {
     if (file.extension() != ".md")
         return nullptr;
@@ -490,7 +470,7 @@ std::unique_ptr<ct_imported_node> CtMDImport::import_file(const fs::path& file)
     _parser->wipe_doc();
     _parser->feed(infile);
 
-    std::unique_ptr<ct_imported_node> node = std::make_unique<ct_imported_node>(file, file.stem().string());
+    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem().string());
     node->xml_content = _parser->doc().document();
 
     return node;
@@ -500,12 +480,12 @@ CtPandocImport::CtPandocImport(CtConfig* config): _config(config)
 {
 }
 
-std::unique_ptr<ct_imported_node> CtPandocImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtPandocImport::import_file(const fs::path& file)
 {
     std::stringstream html_buff;
     CtPandoc::to_html(file, html_buff);
 
-    std::unique_ptr<ct_imported_node> node = std::make_unique<ct_imported_node>(file, file.stem().string());
+    std::unique_ptr<CtImportedNode> node = std::make_unique<CtImportedNode>(file, file.stem().string());
 
     CtHtml2Xml parser(_config);
     parser.set_outter_xml_doc(node->xml_content.get());
@@ -514,7 +494,7 @@ std::unique_ptr<ct_imported_node> CtPandocImport::import_file(const fs::path& fi
     return node;
 }
 
-std::unique_ptr<ct_imported_node> CtKeepnoteImport::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtKeepnoteImport::import_file(const fs::path& file)
 {
     for (auto ignore: {"__TRASH__", "__NOTEBOOK__"})
         if (file.string().find(ignore) != std::string::npos)
@@ -522,29 +502,22 @@ std::unique_ptr<ct_imported_node> CtKeepnoteImport::import_file(const fs::path&
     if (file.filename().string() != "page.html")
         return nullptr;
 
-    std::ifstream infile;
-    infile.exceptions(std::ios::failbit);
-    infile.open(file.string());
-
-    std::ostringstream buff;
-    buff << infile.rdbuf();
-
-    CtHtml2Xml parser(_config);
-    parser.feed(buff.str());
-
-    auto node = std::make_unique<ct_imported_node>(file, file.parent_path().stem().string());
+    std::string keepnoteStr = Glib::file_get_contents(file.string());
+    CtHtml2Xml parser{_config};
+    parser.set_local_dir(file.parent_path().string());
+    parser.feed(keepnoteStr);
+    auto node = std::make_unique<CtImportedNode>(file, file.parent_path().stem().string());
     node->xml_content->create_root_node_by_import(parser.doc().get_root_node());
-    spdlog::debug(buff.str());
-    spdlog::debug(node->xml_content->write_to_string());
-
+    //spdlog::debug(keepnoteStr);
+    //spdlog::debug(node->xml_content->write_to_string());
     return node;
 }
 
 namespace {
 
-std::unique_ptr<ct_imported_node> mempad_page_to_node(const CtMempadParser::page& page, const fs::path& path)
+std::unique_ptr<CtImportedNode> mempad_page_to_node(const CtMempadParser::page& page, const fs::path& path)
 {
-    auto node = std::make_unique<ct_imported_node>(path, page.name);
+    auto node = std::make_unique<CtImportedNode>(path, page.name);
     auto& doc = node->xml_content;
     create_root_plaintext_text_el(*doc, page.contents);
 
@@ -563,7 +536,7 @@ ITER up_to_same_level(ITER start, ITER upper_bound, int level)
     return start;
 }
 
-std::unique_ptr<ct_imported_node> mempad_pages_to_nodes(const CtMempadParser::page& page,
+std::unique_ptr<CtImportedNode> mempad_pages_to_nodes(const CtMempadParser::page& page,
                                                         const std::vector<CtMempadParser::page>& child_pages,
                                                         const fs::path& path)
 {
@@ -582,7 +555,7 @@ std::unique_ptr<ct_imported_node> mempad_pages_to_nodes(const CtMempadParser::pa
     return node;
 }
 
-std::unique_ptr<ct_imported_node> mempad_tree_to_node(const std::vector<CtMempadParser::page>& pages, const fs::path& path)
+std::unique_ptr<CtImportedNode> mempad_tree_to_node(const std::vector<CtMempadParser::page>& pages, const fs::path& path)
 {
     CtMempadParser::page dummy_page{
         .level = 0,
@@ -596,7 +569,7 @@ std::unique_ptr<ct_imported_node> mempad_tree_to_node(const std::vector<CtMempad
 
 } // namespace (anonymous)
 
-std::unique_ptr<ct_imported_node> CtMempadImporter::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtMempadImporter::import_file(const fs::path& file)
 {
     std::ifstream infile{file.string()};
 
@@ -611,7 +584,7 @@ std::unique_ptr<ct_imported_node> CtMempadImporter::import_file(const fs::path&
     return node;
 }
 
-std::unique_ptr<ct_imported_node> CtTreepadImporter::import_file(const fs::path& file)
+std::unique_ptr<CtImportedNode> CtTreepadImporter::import_file(const fs::path& file)
 {
     std::ifstream infile{file.string()};
 
@@ -628,8 +601,8 @@ std::unique_ptr<ct_imported_node> CtTreepadImporter::import_file(const fs::path&
 
 namespace {
 
-std::unique_ptr<ct_imported_node> to_ct_node(const CtLeoParser::leo_node& leo_node, const fs::path& path) {
-    auto node = std::make_unique<ct_imported_node>(path, leo_node.name);
+std::unique_ptr<CtImportedNode> to_ct_node(const CtLeoParser::leo_node& leo_node, const fs::path& path) {
+    auto node = std::make_unique<CtImportedNode>(path, leo_node.name);
     node->xml_content = std::make_shared<xmlpp::Document>();
     create_root_plaintext_text_el(*node->xml_content, leo_node.content);
 
@@ -640,7 +613,7 @@ std::unique_ptr<ct_imported_node> to_ct_node(const CtLeoParser::leo_node& leo_no
     return node;
 }
 
-std::unique_ptr<ct_imported_node> generate_leo_root_node(std::vector<CtLeoParser::leo_node> leo_nodes, const fs::path& path) {
+std::unique_ptr<CtImportedNode> generate_leo_root_node(std::vector<CtLeoParser::leo_node> leo_nodes, const fs::path& path) {
     CtLeoParser::leo_node dummy_node;
     dummy_node.name = "Leo Root";
     dummy_node.children = std::move(leo_nodes);
@@ -648,9 +621,9 @@ std::unique_ptr<ct_imported_node> generate_leo_root_node(std::vector<CtLeoParser
     return to_ct_node(dummy_node, path);
 }
 
-std::unique_ptr<ct_imported_node> node_to_ct_node(const CtRedNotebookParser::node& node, const fs::path& path)
+std::unique_ptr<CtImportedNode> node_to_ct_node(const CtRedNotebookParser::node& node, const fs::path& path)
 {
-    auto ct_node = std::make_unique<ct_imported_node>(path, node.name);
+    auto ct_node = std::make_unique<CtImportedNode>(path, node.name);
 
     if (!node.doc) {
         ct_node->xml_content = std::make_shared<xmlpp::Document>();
@@ -662,7 +635,7 @@ std::unique_ptr<ct_imported_node> node_to_ct_node(const CtRedNotebookParser::nod
     return ct_node;
 }
 
-std::unique_ptr<ct_imported_node> generate_ct_node_hierarchy(std::string&& root_name, const std::vector<CtRedNotebookParser::node>& nodes, const fs::path& path)
+std::unique_ptr<CtImportedNode> generate_ct_node_hierarchy(std::string&& root_name, const std::vector<CtRedNotebookParser::node>& nodes, const fs::path& path)
 {
     CtRedNotebookParser::node root { std::move(root_name) };
     auto ct_root = node_to_ct_node(root, path);
@@ -675,7 +648,7 @@ std::unique_ptr<ct_imported_node> generate_ct_node_hierarchy(std::string&& root_
 
 } // namespace (anonymous)
 
-std::unique_ptr<ct_imported_node> CtLeoImporter::import_file(const fs::path& path)
+std::unique_ptr<CtImportedNode> CtLeoImporter::import_file(const fs::path& path)
 {
     std::ifstream in{path.string()};
     if (!in) {
@@ -688,7 +661,7 @@ std::unique_ptr<ct_imported_node> CtLeoImporter::import_file(const fs::path& pat
     return generate_leo_root_node(parser.nodes(), path);
 }
 
-std::unique_ptr<ct_imported_node> CtRedNotebookImporter::import_file(const fs::path& path)
+std::unique_ptr<CtImportedNode> CtRedNotebookImporter::import_file(const fs::path& path)
 {
     std::ifstream in{path.string()};
     if (!in) {
@@ -698,7 +671,7 @@ std::unique_ptr<ct_imported_node> CtRedNotebookImporter::import_file(const fs::p
     return _parse_input(in, path);
 }
 
-std::unique_ptr<ct_imported_node> CtRedNotebookImporter::_parse_input(std::ifstream& infile, const fs::path& path)
+std::unique_ptr<CtImportedNode> CtRedNotebookImporter::_parse_input(std::ifstream& infile, const fs::path& path)
 {
     CtRedNotebookParser p{_ct_config};
 
@@ -708,7 +681,7 @@ std::unique_ptr<ct_imported_node> CtRedNotebookImporter::_parse_input(std::ifstr
     return generate_ct_node_hierarchy("RedNotebook Root", nodes, path);
 }
 
-std::unique_ptr<ct_imported_node> CtNoteCaseHTMLImporter::import_file(const fs::path& path)
+std::unique_ptr<CtImportedNode> CtNoteCaseHTMLImporter::import_file(const fs::path& path)
 {
     std::ifstream in{path.string()};
     if (!in) {
