@@ -73,6 +73,8 @@ CtMainWin::CtMainWin(bool                            no_gui,
     _hPaned.property_wide_handle() = true;
 
     _pMenuBar = _uCtMenu->build_menubar();
+    _pScrolledWindowMenuBar = Gtk::manage(new Gtk::ScrolledWindow{});
+    _pScrolledWindowMenuBar->add(*_pMenuBar);
     _pMenuBar->set_name("MenuBar");
     _pBookmarksSubmenus[0] = CtMenu::find_menu_item(_pMenuBar, "BookmarksSubMenu");
     auto pPopumMenuTree = _uCtMenu->get_popup_menu(CtMenu::POPUP_MENU_TYPE::Node);
@@ -90,7 +92,19 @@ CtMainWin::CtMainWin(bool                            no_gui,
     add_accel_group(_uCtMenu->get_accel_group());
     _pToolbars = _uCtMenu->build_toolbars(_pRecentDocsMenuToolButton);
 
-    _vboxMain.pack_start(*_pMenuBar, false, false);
+    if (_pCtConfig->menubarInTitlebar) {
+        _pHeaderBar = Gtk::manage(new Gtk::HeaderBar{});
+        _pHeaderBar->set_has_subtitle(false);
+        _pHeaderBar->set_show_close_button(true);
+        _pHeaderBar->pack_start(*Gtk::manage(new Gtk::Label{" "}));
+        _pHeaderBar->pack_start(*_pScrolledWindowMenuBar);
+        _pHeaderBar->pack_start(*Gtk::manage(new Gtk::Label{" "}));
+        _pHeaderBar->show_all();
+        set_titlebar(*_pHeaderBar);
+    }
+    else {
+        _vboxMain.pack_start(*_pScrolledWindowMenuBar, false, false);
+    }
     for (auto pToolbar : _pToolbars) {
         _vboxMain.pack_start(*pToolbar, false, false);
     }
@@ -236,6 +250,7 @@ void CtMainWin::_reset_CtTreestore_CtTreeview()
     _uCtTreestore->tree_view_connect(_uCtTreeview.get());
     _uCtTreeview->set_tree_node_name_wrap_width(_pCtConfig->cherryWrapEnabled, _pCtConfig->cherryWrapWidth);
     _uCtTreeview->get_column(CtTreeView::AUX_ICON_COL_NUM)->set_visible(!_pCtConfig->auxIconHide);
+    show_hide_tree_lines(_pCtConfig->treeLinesVisible);
 
     _tree_just_auto_expanded = false;
     _uCtTreeview->signal_cursor_changed().connect(sigc::mem_fun(*this, &CtMainWin::_on_treeview_cursor_changed));
@@ -270,11 +285,14 @@ void CtMainWin::config_apply()
     }
 
     show_hide_tree_view(_pCtConfig->treeVisible);
+    show_hide_menubar(_pCtConfig->menubarVisible);
     show_hide_win_header(_pCtConfig->showNodeNameHeader);
     _ctWinHeader.lockIcon.hide();
     _ctWinHeader.bookmarkIcon.hide();
+    _ctWinHeader.ghostIcon.hide();
 
     menu_rebuild_toolbars(false);
+    show_hide_statusbar(_pCtConfig->statusbarVisible);
 
     _ctStatusBar.progressBar.hide();
     _ctStatusBar.stopButton.hide();
@@ -332,7 +350,7 @@ void CtMainWin::update_theme()
     css_str += ".ct-tree-panel" + treeFont;
     css_str += " ";
     css_str += ".ct-tree-panel { color: " + _pCtConfig->ttDefFg + "; background-color: " + _pCtConfig->ttDefBg + "; } ";
-    css_str += ".ct-tree-panel:selected { color: " + _pCtConfig->ttDefBg + "; background: #5294e2; } ";
+    css_str += ".ct-tree-panel:selected { color: " + _pCtConfig->ttSelFg + "; background: " + _pCtConfig->ttSelBg + "; } ";
     css_str += ".ct-tree-scroll-panel { background-color: " + _pCtConfig->ttDefBg + "; } ";
     css_str += ".ct-header-panel { background-color: " + _pCtConfig->ttDefBg + "; } ";
     css_str += ".ct-header-panel button { margin: 2px; padding: 0 4px 0 4px; } ";
@@ -387,10 +405,13 @@ Gtk::EventBox& CtMainWin::_init_window_header()
     _ctWinHeader.lockIcon.hide();
     _ctWinHeader.bookmarkIcon.set_from_icon_name("ct_pin", Gtk::ICON_SIZE_MENU);
     _ctWinHeader.bookmarkIcon.hide();
+    _ctWinHeader.ghostIcon.set_from_icon_name("ct_ghost", Gtk::ICON_SIZE_MENU);
+    _ctWinHeader.ghostIcon.hide();
     _ctWinHeader.headerBox.pack_start(_ctWinHeader.buttonBox, false, false);
     _ctWinHeader.headerBox.pack_start(_ctWinHeader.nameLabel, true, true);
     _ctWinHeader.headerBox.pack_start(_ctWinHeader.lockIcon, false, false);
     _ctWinHeader.headerBox.pack_start(_ctWinHeader.bookmarkIcon, false, false);
+    _ctWinHeader.headerBox.pack_start(_ctWinHeader.ghostIcon, false, false);
     _ctWinHeader.eventBox.add(_ctWinHeader.headerBox);
     _ctWinHeader.eventBox.get_style_context()->add_class("ct-header-panel");
     return _ctWinHeader.eventBox;
@@ -462,12 +483,17 @@ void CtMainWin::window_header_update()
     }
 }
 
-void CtMainWin::window_header_update_lock_icon(bool show)
+void CtMainWin::window_header_update_lock_icon(const bool show)
 {
     _ctWinHeader.lockIcon.set_visible(show);
 }
 
-void CtMainWin::window_header_update_bookmark_icon(bool show)
+void CtMainWin::window_header_update_ghost_icon(const bool show)
+{
+    _ctWinHeader.ghostIcon.set_visible(show);
+}
+
+void CtMainWin::window_header_update_bookmark_icon(const bool show)
 {
     _ctWinHeader.bookmarkIcon.set_visible(show);
 }
@@ -624,6 +650,7 @@ void CtMainWin::reset()
     }
     _ctWinHeader.nameLabel.set_markup("");
     window_header_update_lock_icon(false);
+    window_header_update_ghost_icon(false);
     window_header_update_bookmark_icon(false);
     menu_set_bookmark_menu_items();
     _uCtMenu->find_action("ct_vacuum")->signal_set_visible.emit(false);
