@@ -32,7 +32,11 @@
 #include <regex>
 #include <glib/gstdio.h> // to get stats
 #include <curl/curl.h>
+#ifndef __APPLE__
+#include <uchardet/uchardet.h>
+#else
 #include <uchardet.h>
+#endif // __APPLE__
 #include <thread> // for parallel_for
 #include <future> // parallel_for
 
@@ -131,16 +135,14 @@ void table_to_csv(const CtStringTable& table, std::ostream& output) {
 std::string CtMiscUtil::get_ct_language()
 {
     std::string retLang{CtConst::LANG_DEFAULT};
-    if (fs::is_regular_file(fs::get_cherrytree_lang_filepath()))
-    {
-        const std::string langTxt = str::trim(Glib::file_get_contents(fs::get_cherrytree_lang_filepath().string()));
-        if (vec::exists(CtConst::AVAILABLE_LANGS, langTxt))
-        {
+    const fs::path langcfgFilepath = fs::get_cherrytree_langcfg_filepath();
+    if (fs::is_regular_file(langcfgFilepath)) {
+        const std::string langTxt = str::trim(Glib::file_get_contents(langcfgFilepath.string()));
+        if (vec::exists(CtConst::AVAILABLE_LANGS, langTxt)) {
             retLang = langTxt;
         }
-        else
-        {
-            g_critical("Unexpected %s file content %s", fs::get_cherrytree_lang_filepath().c_str(), langTxt.c_str());
+        else {
+            g_critical("Unexpected %s file content %s", langcfgFilepath.c_str(), langTxt.c_str());
         }
     }
     return retLang;
@@ -279,16 +281,21 @@ CtLinkEntry CtMiscUtil::get_link_entry(const Glib::ustring& link)
     return link_entry;
 }
 
-bool CtMiscUtil::mime_type_contains(const std::string &filepath, const std::string& type)
+bool CtMiscUtil::mime_type_contains(const std::string &filepath, const char* type)
 {
-    using gchar_ptr = std::unique_ptr<gchar, decltype(&g_free)>;
+    GFile* pGFile = g_file_new_for_path(filepath.c_str());
+    g_autoptr(GError) pGError{nullptr};
+    GFileInfo* pGFileInfo = g_file_query_info(pGFile,
+                                              "standard::*",
+                                              G_FILE_QUERY_INFO_NONE,
+                                              NULL,
+                                              &pGError);
+    const char* content_type = g_file_info_get_content_type(pGFileInfo);
+    g_autofree gchar* mime_type = g_content_type_get_mime_type(content_type);
+    g_object_unref(pGFileInfo);
+    g_object_unref(pGFile);
 
-    // Note that these return gchar* which must be freed with g_free()
-    gchar_ptr type_guess(g_content_type_guess(filepath.c_str(), nullptr, 0, nullptr), g_free);
-    gchar_ptr p_mime_type(g_content_type_get_mime_type(type_guess.get()), g_free);
-    std::string mime_type = p_mime_type.get();
-
-    return mime_type.find(type) != std::string::npos;
+    return strstr(mime_type, type);
 }
 
 namespace CtMiscUtil {
@@ -677,22 +684,21 @@ std::string CtStrUtil::get_internal_link_from_http_url(std::string link_url)
 std::string CtStrUtil::get_encoding(const char* const pData, const size_t dataLen)
 {
     std::string charset;
-    if (dataLen >=4 && memcmp(pData, "\x84\x31\x95\x33", 4) == 0) {
-        charset = "GB-18030";
-    }
-    else if (dataLen >= 4 && memcmp(pData, "\x00\x00\xFE\xFF", 4) == 0) {
-        charset = "UTF-32BE";
-    }
-    else if (dataLen>= 4 && memcmp(pData, "\xFF\xFE\x00\x00", 4) == 0) {
-        charset = "UTF-32LE";
-    }
-    else if (dataLen >= 2 && memcmp(pData, "\xFE\xFF", 2) == 0) {
-        charset = "UTF-16BE";
-    }
-    else if (dataLen >= 2 && memcmp(pData, "\xFF\xFE", 2) == 0) {
-        charset = "UTF-16LE";
-    }
+    // look at the BOM first if present
+    // https://en.wikipedia.org/wiki/Byte_order_mark
+    if      (g_str_has_prefix(pData,             "\xEF\xBB\xBF"))        { charset = "UTF-8"; }
+    else if (dataLen >= 4 and 0 == memcmp(pData, "\x00\x00\xFE\xFF", 4)) { charset = "UTF-32BE"; }
+    else if (dataLen >= 4 and 0 == memcmp(pData, "\xFF\xFE\x00\x00", 4)) { charset = "UTF-32LE"; }
+    else if (g_str_has_prefix(pData,             "\xFE\xFF"))            { charset = "UTF-16BE"; }
+    else if (g_str_has_prefix(pData,             "\xFF\xFE"))            { charset = "UTF-16LE"; }
+    else if (g_str_has_prefix(pData,             "\x2B\x2F\x76"))        { charset = "UTF-7"; }
+    else if (g_str_has_prefix(pData,             "\xF7\x64\x4C"))        { charset = "UTF-1"; }
+    else if (g_str_has_prefix(pData,             "\xDD\x73\x66\x73"))    { charset = "UTF-EBCDIC"; }
+    else if (g_str_has_prefix(pData,             "\x0E\xFE\xFF"))        { charset = "SCSU"; }
+    else if (g_str_has_prefix(pData,             "\xFB\xEE\x28"))        { charset = "BOCU-1"; }
+    else if (g_str_has_prefix(pData,             "\x84\x31\x95\x33"))    { charset = "GB-18030"; }
     else {
+        // no BOM, try with uchardet
         uchardet_t handle = uchardet_new();
         if (0 == uchardet_handle_data(handle, pData, dataLen)) {
             uchardet_data_end(handle);
@@ -709,13 +715,32 @@ bool CtStrUtil::is_codeset_not_utf8(const std::string& codeset)
     return not codeset.empty() and codeset != "ASCII" and codeset != "UTF-8";
 }
 
-Glib::ustring CtStrUtil::convert_raw_to_utf8(const std::string& rawText)
+void CtStrUtil::convert_if_not_utf8(std::string& inOutText, const bool sanitise)
 {
-    const std::string codeset = CtStrUtil::get_encoding(rawText.c_str(), rawText.size());
+    const std::string codeset = CtStrUtil::get_encoding(inOutText.c_str(), inOutText.size());
     if (CtStrUtil::is_codeset_not_utf8(codeset)) {
-        return Glib::convert_with_fallback(rawText, "UTF-8", codeset);
+        gsize bytes_read, bytes_written;
+        g_autofree gchar* pConverted = g_convert_with_fallback(
+            inOutText.c_str(), inOutText.size(), "UTF-8", codeset.c_str(), "?"/*fallback*/,
+            &bytes_read, &bytes_written, NULL);
+        if (pConverted) {
+            // ok converted
+            if (g_str_has_prefix(pConverted, "\xEF\xBB\xBF")) {
+                // remove UTF-8 BOM
+                inOutText = std::string{pConverted+3, bytes_written-3};
+            }
+            else {
+                inOutText = std::string{pConverted, bytes_written};
+            }
+        }
+    }
+    else if (Glib::str_has_prefix(inOutText, "\xEF\xBB\xBF")) {
+        // remove UTF-8 BOM
+        inOutText = inOutText.substr(3);
+    }
+    if (sanitise) {
+        inOutText = str::sanitize_bad_symbols(inOutText);
     }
-    return rawText;
 }
 
 Glib::ustring CtFontUtil::get_font_family(const Glib::ustring& fontStr)
@@ -930,7 +955,12 @@ Glib::ustring str::time_format(const std::string& format, const time_t& time)
     if (g_utf8_validate(buffer, len, NULL)) return buffer;
 
     g_autofree gchar* date = g_locale_to_utf8(buffer, len, NULL, NULL, NULL);
-    return date;
+    if (date) return date;
+
+    const std::string codeset = CtStrUtil::get_encoding(buffer, len);
+    std::string converted{buffer, len};
+    CtStrUtil::convert_if_not_utf8(converted, true/*sanitise*/);
+    return converted;
 }
 
 int str::symb_pos_to_byte_pos(const Glib::ustring& text, int symb_pos)
