@@ -1,7 +1,7 @@
 /*
  * ct_misc_utils.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -28,58 +28,10 @@
 #include <gtksourceviewmm.h>
 #include <gtkmm/treeiter.h>
 #include <gtkmm/treestore.h>
-#include <unordered_set>
-#include <type_traits>
-#include <deque>
-#include <mutex>
-#include <optional>
-#include <condition_variable>
 
 class CtConfig;
 class CtTreeIter;
 
-using CtCurrAttributesMap = std::unordered_map<std::string_view, std::string>;
-
-template<class F> auto scope_guard(F&& f) {
-    return std::unique_ptr<void, typename std::decay<F>::type>{(void*)1, std::forward<F>(f)};
-}
-
-template <class T> class ThreadSafeDEQueue
-{
-public:
-    void push_back(T t) {
-        std::lock_guard<std::mutex> lock(m);
-        q.push_back(t);
-        c.notify_one();
-    }
-    T pop_front() {
-        std::unique_lock<std::mutex> lock(m);
-        while (q.empty()) {
-            c.wait(lock);
-        }
-        T val = q.front();
-        q.pop_front();
-        return val;
-    }
-    std::optional<T> peek() {
-        std::optional<T> retVal;
-        std::lock_guard<std::mutex> lock(m);
-        if (not q.empty()) {
-            retVal = q.front();
-        }
-        return retVal;
-    }
-    bool empty() const {
-        std::lock_guard<std::mutex> lock(m);
-        return q.empty();
-    }
-
-private:
-    std::deque<T> q{};
-    mutable std::mutex m{};
-    std::condition_variable c{};
-};
-
 namespace CtCSV {
     using CtStringTable = std::vector<std::vector<std::string>>;
     CtStringTable table_from_csv(std::istream& input);
@@ -110,7 +62,7 @@ CtLinkEntry get_link_entry(const Glib::ustring& link);
  * @brief Check if the the mime for a file contains a given string
  * @return
  */
-bool mime_type_contains(const std::string& filepath, const std::string& type);
+bool mime_type_contains(const std::string& filepath, const char* type);
 
 enum class URI_TYPE { LOCAL_FILEPATH, WEB_URL, UNKNOWN };
 URI_TYPE get_uri_type(const std::string& uri);
@@ -241,7 +193,7 @@ std::string get_encoding(const char* const pData, const size_t dataLen);
 
 bool is_codeset_not_utf8(const std::string& codeset);
 
-Glib::ustring convert_raw_to_utf8(const std::string& rawData);
+void convert_if_not_utf8(std::string& inOutText, const bool sanitise);
 
 } // namespace CtStrUtil
 
