@@ -1,7 +1,7 @@
 /*
  * ct_pref_dlg.h
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -31,6 +31,7 @@
 #include "ct_menu.h"
 
 class CtMainWin;
+class CtConfig;
 
 class CtPrefDlg : public Gtk::Dialog
 {
@@ -40,6 +41,7 @@ public:
 private:
     Gtk::Widget* build_tab_text_n_code();
     Gtk::Widget* build_tab_rich_text();
+    Gtk::Widget* build_tab_format();
     Gtk::Widget* build_tab_plain_text_n_code();
     Gtk::Widget* build_tab_special_characters();
     Gtk::Widget* build_tab_tree();
@@ -51,14 +53,14 @@ private:
     Gtk::Widget* build_tab_misc();
 
 private:
-    enum RESTART_REASON {MONOSPACE         = 1 << 0, EMBFILE_SIZE       = 1 << 1,
-                         SHOW_EMBFILE_NAME = 1 << 2, LINKS              = 1 << 3,
-                         ANCHOR_SIZE       = 1 << 4, COLOR              = 1 << 5,
-                         SCHEME            = 1 << 6, LANG               = 1 << 7,
-                         SHORTCUT          = 1 << 8, CODEBOX_AUTORESIZE = 1 << 9,
-                         TREE_NODE_WRAP    = 1 << 10};
+    enum RESTART_REASON {MONOSPACE         = 1 << 0,  EMBFILE_SIZE       = 1 << 1,
+                         SHOW_EMBFILE_NAME = 1 << 2,  LINKS              = 1 << 3,
+                         ANCHOR_SIZE       = 1 << 4,  COLOR              = 1 << 5,
+                         SCALABLE_TAGS     = 1 << 6,  LANG               = 1 << 7,
+                         SHORTCUT          = 1 << 8,  CODEBOX_AUTORESIZE = 1 << 9,
+                         TREE_NODE_WRAP    = 1 << 10, DEBUG_LOG          = 1 << 11};
 
-    const Glib::ustring reset_warning = Glib::ustring("<b>")+_("Are you sure to Reset to Default?")+"</b>";
+    const Glib::ustring reset_warning = Glib::ustring{"<b>"}+_("Are you sure to Reset to Default?")+"</b>";
 
 private:
     void need_restart(RESTART_REASON reason, const gchar* msg = nullptr);
@@ -100,7 +102,9 @@ private:
     UniversalModelColumns _commandModelColumns;
     UniversalModelColumns _toolbarModelColumns;
     UniversalModelColumns _shortcutModelColumns;
-    CtMainWin*            _pCtMainWin;
-    CtMenu*               _pCtMenu;
-    int                   _restartReasons;
+    CtMainWin* const      _pCtMainWin;
+    CtMenu* const         _pCtMenu;
+    CtConfig* const       _pConfig;
+    int                   _restartReasons{0};
+    const std::map<std::string, Glib::ustring> _mapCountryLanguages;
 };
