@@ -148,7 +148,7 @@ void CtStorageXml::vacuum()
 {
 }
 
-void CtStorageXml::import_nodes(const fs::path& path)
+void CtStorageXml::import_nodes(const fs::path& path, const Gtk::TreeIter& parent_iter)
 {
     auto parser = _get_parser(path);
 
@@ -158,13 +158,15 @@ void CtStorageXml::import_nodes(const fs::path& path)
         new_iter.pending_new_db_node();
 
         gint64 child_sequence = 0;
-        for (xmlpp::Node* xml_node : xml_element->get_children("node"))
+        for (xmlpp::Node* xml_node : xml_element->get_children("node")) {
             recursive_import_func(static_cast<xmlpp::Element*>(xml_node), ++child_sequence, new_iter);
+        }
     };
 
     gint64 sequence = 0;
-    for (xmlpp::Node* xml_node: parser->get_document()->get_root_node()->get_children("node"))
-        recursive_import_func(static_cast<xmlpp::Element*>(xml_node), ++sequence, _pCtMainWin->get_tree_store().to_ct_tree_iter(Gtk::TreeIter()));
+    for (xmlpp::Node* xml_node : parser->get_document()->get_root_node()->get_children("node")) {
+        recursive_import_func(static_cast<xmlpp::Element*>(xml_node), ++sequence, _pCtMainWin->get_tree_store().to_ct_tree_iter(parent_iter));
+    }
 }
 
 Glib::RefPtr<Gsv::Buffer> CtStorageXml::get_delayed_text_buffer(const gint64& node_id,
@@ -194,7 +196,9 @@ Gtk::TreeIter CtStorageXml::_node_from_xml(xmlpp::Element* xml_element, gint64 s
     node_data.name = xml_element->get_attribute_value("name");
     node_data.syntax = xml_element->get_attribute_value("prog_lang");
     node_data.tags = xml_element->get_attribute_value("tags");
-    node_data.isRO = CtStrUtil::is_str_true(xml_element->get_attribute_value("readonly"));
+    node_data.isReadOnly = CtStrUtil::is_str_true(xml_element->get_attribute_value("readonly"));
+    node_data.excludeMeFromSearch = CtStrUtil::is_str_true(xml_element->get_attribute_value("nosearch_me"));
+    node_data.excludeChildrenFromSearch = CtStrUtil::is_str_true(xml_element->get_attribute_value("nosearch_ch"));
     node_data.customIconId = (guint32)CtStrUtil::gint64_from_gstring(xml_element->get_attribute_value("custom_icon_id").c_str());
     node_data.isBold = CtStrUtil::is_str_true(xml_element->get_attribute_value("is_bold"));
     node_data.foregroundRgb24 = xml_element->get_attribute_value("foreground");
@@ -265,11 +269,8 @@ std::unique_ptr<xmlpp::DomParser> CtStorageXml::_get_parser(const fs::path& file
     catch (xmlpp::exception& e) {
         spdlog::error("{} {} {}", __FUNCTION__, file_path.string(), e.what());
 
-        std::string buffer = fs::get_content(file_path);
-        const std::string codeset = CtStrUtil::get_encoding(buffer.c_str(), buffer.size());
-        if (CtStrUtil::is_codeset_not_utf8(codeset)) {
-            buffer = Glib::convert_with_fallback(buffer, "UTF-8", codeset);
-        }
+        std::string buffer = Glib::file_get_contents(file_path.string());
+        CtStrUtil::convert_if_not_utf8(buffer, true/*sanitise*/);
         parseOk = CtXmlHelper::safe_parse_memory(*parser, buffer);
     }
 
@@ -303,6 +304,8 @@ xmlpp::Element* CtStorageXmlHelper::node_to_xml(CtTreeIter* ct_tree_iter,
     p_node_node->set_attribute("prog_lang", ct_tree_iter->get_node_syntax_highlighting());
     p_node_node->set_attribute("tags", ct_tree_iter->get_node_tags());
     p_node_node->set_attribute("readonly", std::to_string(ct_tree_iter->get_node_read_only()));
+    p_node_node->set_attribute("nosearch_me", std::to_string(ct_tree_iter->get_node_is_excluded_from_search()));
+    p_node_node->set_attribute("nosearch_ch", std::to_string(ct_tree_iter->get_node_children_are_excluded_from_search()));
     p_node_node->set_attribute("custom_icon_id", std::to_string(ct_tree_iter->get_node_custom_icon_id()));
     p_node_node->set_attribute("is_bold", std::to_string(ct_tree_iter->get_node_is_bold()));
     p_node_node->set_attribute("foreground", ct_tree_iter->get_node_foreground());
@@ -552,18 +555,35 @@ void CtXmlHelper::table_to_xml(xmlpp::Element* p_parent,
 
 bool CtXmlHelper::safe_parse_memory(xmlpp::DomParser& parser, const Glib::ustring& xml_content)
 {
+    bool parseOk{false};
     try {
         parser.parse_memory(xml_content);
+        parseOk = true;
     }
     catch (xmlpp::parse_error& e) {
-        spdlog::error("{} {}", __FUNCTION__, e.what());
+        spdlog::error("{} [1] {}", __FUNCTION__, e.what());
+    }
+    if (not parseOk) {
+        g_autofree gchar* pMadeValid = g_utf8_make_valid(xml_content.c_str(), xml_content.bytes());
         try {
-            parser.parse_memory(str::sanitize_bad_symbols(xml_content));
-            spdlog::info("{} xml sanitised", __FUNCTION__);
+            parser.parse_memory(pMadeValid);
+            parseOk = true;
         }
-        catch (std::exception& e) {
-            spdlog::error("{} {}", __FUNCTION__, e.what());
-            return false;
+        catch (xmlpp::parse_error& e) {
+            spdlog::error("{} [2] {}", __FUNCTION__, e.what());
+        }
+        if (not parseOk) {
+            auto sanitised = str::sanitize_bad_symbols(pMadeValid);
+            try {
+                parser.parse_memory(sanitised);
+                parseOk = true;
+            }
+            catch (xmlpp::parse_error& e) {
+                spdlog::error("{} [3] {}", __FUNCTION__, e.what());
+            }
+            if (not parseOk) {
+                return false;
+            }
         }
     }
     return parser.get_document() and parser.get_document()->get_root_node();
