@@ -1,7 +1,7 @@
 /*
  * tests_filesystem.cpp
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -23,7 +23,7 @@
 
 #include "ct_filesystem.h"
 #include "tests_common.h"
-#include <fstream>
+#include <glibmm.h>
 
 TEST(FileSystemGroup, path_stem)
 {
@@ -67,26 +67,26 @@ TEST(FileSystemGroup, get_cherrytree_localedir)
 
 TEST(FileSystemGroup, is_regular_file)
 {
-    ASSERT_EQ(true, fs::is_regular_file(UT::unitTestsDataDir + "/test.ctd"));
-    ASSERT_EQ(true, fs::is_regular_file(UT::unitTestsDataDir + "/test.ctb"));
-    ASSERT_EQ(true, fs::is_regular_file(UT::unitTestsDataDir + "/md_testfile.md"));
-    ASSERT_EQ(false, fs::is_regular_file(UT::unitTestsDataDir));
-    ASSERT_EQ(false, fs::is_regular_file(fs::absolute(UT::unitTestsDataDir)));
-    ASSERT_EQ(false, fs::is_regular_file(fs::absolute(UT::unitTestsDataDir).parent_path()));
+    ASSERT_TRUE(fs::is_regular_file(UT::testCtdDocPath));
+    ASSERT_TRUE(fs::is_regular_file(UT::testCtbDocPath));
+    ASSERT_TRUE(fs::is_regular_file(UT::unitTestsDataDir + "/md_testfile.md"));
+    ASSERT_FALSE(fs::is_regular_file(UT::unitTestsDataDir));
+    ASSERT_FALSE(fs::is_regular_file(fs::absolute(UT::unitTestsDataDir)));
+    ASSERT_FALSE(fs::is_regular_file(fs::absolute(UT::unitTestsDataDir).parent_path()));
 }
 
 TEST(FileSystemGroup, is_directory)
 {
-    ASSERT_EQ(true, fs::is_directory(UT::unitTestsDataDir));
-    ASSERT_EQ(false, fs::is_directory(UT::unitTestsDataDir + "/test.ctd"));
-    ASSERT_EQ(true, fs::is_directory(fs::path(UT::unitTestsDataDir).parent_path()));
-    ASSERT_EQ(false, fs::is_directory(fs::path(UT::unitTestsDataDir).parent_path() / "test_consts.h"));
+    ASSERT_TRUE(fs::is_directory(UT::unitTestsDataDir));
+    ASSERT_FALSE(fs::is_directory(UT::testCtdDocPath));
+    ASSERT_TRUE(fs::is_directory(fs::path(UT::unitTestsDataDir).parent_path()));
+    ASSERT_FALSE(fs::is_directory(fs::path(UT::unitTestsDataDir).parent_path() / "test_consts.h"));
 }
 
 TEST(FileSystemGroup, get_doc_type)
 {
-    ASSERT_TRUE(CtDocType::SQLite == fs::get_doc_type(UT::unitTestsDataDir + "/test.ctb"));
-    ASSERT_TRUE(CtDocType::XML == fs::get_doc_type(UT::unitTestsDataDir + "/test.ctd"));
+    ASSERT_TRUE(CtDocType::SQLite == fs::get_doc_type(UT::testCtbDocPath));
+    ASSERT_TRUE(CtDocType::XML == fs::get_doc_type(UT::testCtdDocPath));
     ASSERT_TRUE(CtDocType::None == fs::get_doc_type(UT::unitTestsDataDir + "/md_testfile.md"));
     ASSERT_TRUE(CtDocType::SQLite == fs::get_doc_type(UT::unitTestsDataDir + "/mimetype_ctb.ctb"));
     ASSERT_TRUE(CtDocType::XML == fs::get_doc_type(UT::unitTestsDataDir + "/7zr.ctz"));
@@ -95,17 +95,17 @@ TEST(FileSystemGroup, get_doc_type)
 
 TEST(FileSystemGroup, get_doc_encrypt)
 {
-    ASSERT_TRUE(fs::get_doc_encrypt(UT::unitTestsDataDir + "/test.ctb") == CtDocEncrypt::False);
-    ASSERT_TRUE(fs::get_doc_encrypt(UT::unitTestsDataDir + "/test.ctz") == CtDocEncrypt::True);
+    ASSERT_TRUE(fs::get_doc_encrypt(UT::testCtbDocPath) == CtDocEncrypt::False);
+    ASSERT_TRUE(fs::get_doc_encrypt(UT::testCtzDocPath) == CtDocEncrypt::True);
     ASSERT_TRUE(fs::get_doc_encrypt(UT::unitTestsDataDir + "/mimetype_txt.txt") == CtDocEncrypt::None);
 }
 
 TEST(FileSystemGroup, path_is_absolute)
 {
-    ASSERT_EQ(true, fs::path("/home/foo").is_absolute());
-    ASSERT_EQ(false, fs::path("/home/foo").is_relative());
-    ASSERT_EQ(true, fs::path("home/foo").is_relative());
-    ASSERT_EQ(false, fs::path("home/foo").is_absolute());
+    ASSERT_TRUE(fs::path("/home/foo").is_absolute());
+    ASSERT_FALSE(fs::path("/home/foo").is_relative());
+    ASSERT_TRUE(fs::path("home/foo").is_relative());
+    ASSERT_FALSE(fs::path("home/foo").is_absolute());
 }
 
 TEST(FileSystemGroup, path_parent_path)
@@ -130,20 +130,22 @@ TEST(FileSystemGroup, path_native)
 #else
     std::string first = "\\foo";
 #endif
-    fs::path path("/foo");
+    fs::path p("/foo");
+    ASSERT_STREQ(p.string_native().c_str(), first.c_str());
+}
 
-    ASSERT_STREQ(path.native().c_str(), first.c_str());
+TEST(FileSystemGroup, path_unix)
+{
+    fs::path p("C:\\foo\\bar");
+    std::string first = "C:/foo/bar";
+    ASSERT_STREQ(p.string_unix().c_str(), first.c_str());
 }
 
 TEST(FileSystemGroup, remove)
 {
     // file remove
     fs::path test_file_path = fs::path{UT::unitTestsDataDir} / fs::path{"test_file.txt"};
-    {
-        std::ofstream test_file_ofstr{test_file_path.string()};
-        test_file_ofstr << "blabla";
-        test_file_ofstr.close();
-    }
+    Glib::file_set_contents(test_file_path.string(), "blabla");
     ASSERT_TRUE(fs::exists(test_file_path));
 
     ASSERT_TRUE(fs::remove(test_file_path));
@@ -161,32 +163,12 @@ TEST(FileSystemGroup, remove)
     // non empty dir remove
     ASSERT_EQ(0, g_mkdir_with_parents(test_dir_path.c_str(), 0777));
     fs::path test_file_in_dir = test_dir_path / fs::path{"test_file.txt"};
-    {
-        std::ofstream test_file_in_dir_ofstr{test_file_in_dir.string()};
-        test_file_in_dir_ofstr << "blabla";
-        test_file_in_dir_ofstr.close();
-    }
+    Glib::file_set_contents(test_file_in_dir.string(), "blabla");
     ASSERT_TRUE(fs::exists(test_file_in_dir));
     ASSERT_EQ(2, fs::remove_all(test_dir_path));
     ASSERT_FALSE(fs::exists(test_dir_path));
 }
 
-TEST(FileSystemGroup, get_content)
-{
-    std::string content = "blabla";
-    fs::path test_file_path = fs::path{UT::unitTestsDataDir} / fs::path{"test_file.txt"};
-    {
-        fs::remove(test_file_path);
-        std::ofstream test_file_ofstr{test_file_path.string()};
-        test_file_ofstr << content;
-        test_file_ofstr.close();
-    }
-
-    ASSERT_STREQ(content.c_str(), fs::get_content(test_file_path.c_str()).c_str());
-
-    fs::remove(test_file_path);
-}
-
 TEST(FileSystemGroup, relative)
 {
 #ifdef _WIN32
@@ -202,3 +184,18 @@ TEST(FileSystemGroup, relative)
     ASSERT_STREQ("../../test.txt", fs::relative("/tmp/test.txt", "/tmp/one/two").c_str());
 #endif // _WIN32
 }
+
+TEST(FileSystemGroup, canonicalize_filename)
+{
+#ifdef _WIN32
+    ASSERT_STREQ("C:\\opt\\one\\two\\three.txt", fs_canonicalize_filename("two\\three.txt", "C:\\opt\\one").c_str());
+    ASSERT_STREQ("C:\\opt\\one\\two\\three.txt", fs_canonicalize_filename(".\\two\\three.txt", "C:\\opt\\one").c_str());
+    ASSERT_STREQ("C:\\opt\\one\\two\\three.txt", fs_canonicalize_filename("..\\two\\three.txt", "C:\\opt\\one\\four").c_str());
+    ASSERT_STREQ("C:\\opt\\one\\two\\three.txt", fs_canonicalize_filename("C:\\opt\\one\\two\\three.txt", "C:\\four\\five").c_str());
+#else
+    ASSERT_STREQ("/opt/one/two/three.txt", fs_canonicalize_filename("two/three.txt", "/opt/one").c_str());
+    ASSERT_STREQ("/opt/one/two/three.txt", fs_canonicalize_filename("./two/three.txt", "/opt/one").c_str());
+    ASSERT_STREQ("/opt/one/two/three.txt", fs_canonicalize_filename("../two/three.txt", "/opt/one/four").c_str());
+    ASSERT_STREQ("/opt/one/two/three.txt", fs_canonicalize_filename("/opt/one/two/three.txt", "/four/five").c_str());
+#endif
+}
