@@ -1,7 +1,7 @@
 /*
  * tests_misc_utils.cpp
  *
- * Copyright 2009-2020
+ * Copyright 2009-2021
  * Giuseppe Penone <giuspen@gmail.com>
  * Evgenii Gurianov <https://github.com/txe>
  *
@@ -27,82 +27,32 @@
 #include "tests_common.h"
 #include <thread>
 
-TEST(MiscUtilsGroup, scope_guard)
-{
-    int var = -1;
-    {
-        auto on_scope_exit = scope_guard([&](void*) {
-            var = 0;
-        });
-        ASSERT_EQ(-1, var);
-    }
-    ASSERT_EQ(0, var);
-}
-
-TEST(MiscUtilsGroup, ThreadSafeDEQueue_1)
-{
-    ThreadSafeDEQueue<int> threadSafeDEQueue;
-    auto f_first = [&threadSafeDEQueue](){
-        ASSERT_EQ(1, threadSafeDEQueue.pop_front());
-        threadSafeDEQueue.push_back(2);
-        while (true) {
-            g_usleep(1);
-            std::optional<int> peeked = threadSafeDEQueue.peek();
-            if (not peeked.has_value() or 3 == peeked.value()) {
-                break;
-            }
-        }
-        ASSERT_EQ(3, threadSafeDEQueue.pop_front());
-    };
-    auto f_second = [&threadSafeDEQueue](){
-        ASSERT_TRUE(threadSafeDEQueue.empty());
-        threadSafeDEQueue.push_back(1);
-        while (true) {
-            g_usleep(1);
-            std::optional<int> peeked = threadSafeDEQueue.peek();
-            if (not peeked.has_value() or 2 == peeked.value()) {
-                break;
-            }
-        }
-        ASSERT_EQ(2, threadSafeDEQueue.pop_front());
-        threadSafeDEQueue.push_back(3);
-    };
-    std::thread first(f_first);
-    std::thread second(f_second);
-    first.join();
-    second.join();
-}
-
-TEST(MiscUtilsGroup, ThreadSafeDEQueue_2)
-{
-    ThreadSafeDEQueue<int> threadSafeDEQueue;
-    auto f_first = [&threadSafeDEQueue](){
-        for (int i = 0; i < 100; ++i) {
-            g_usleep(1);
-            threadSafeDEQueue.push_back(i);
-        }
-    };
-    auto f_second = [&threadSafeDEQueue](){
-        for (int i = 0; i < 200; ++i) {
-            threadSafeDEQueue.pop_front();
-        }
-    };
-    std::thread first(f_first);
-    std::thread second(f_second);
-    std::thread third(f_first);
-    ASSERT_TRUE(threadSafeDEQueue.empty());
-    first.join();
-    second.join();
-    third.join();
-}
-
-TEST(MiscUtilsGroup, files_encodings)
+TEST(MiscUtilsGroup, get_encoding)
 {
     auto _get_file_encoding = [](const std::string& inFilepath)->std::string{
         std::string inString = Glib::file_get_contents(inFilepath);
         return CtStrUtil::get_encoding(inString.c_str(), inString.size());
     };
     ASSERT_STREQ("UTF-8", _get_file_encoding(UT::testCtdDocPath).c_str());
+    ASSERT_STREQ("UTF-8", _get_file_encoding(UT::testBomUtf8Path).c_str());
+    ASSERT_STREQ("UTF-32BE", _get_file_encoding(UT::testBomUtf32BEPath).c_str());
+    ASSERT_STREQ("UTF-32LE", _get_file_encoding(UT::testBomUtf32LEPath).c_str());
+    ASSERT_STREQ("UTF-16BE", _get_file_encoding(UT::testBomUtf16BEPath).c_str());
+    ASSERT_STREQ("UTF-16LE", _get_file_encoding(UT::testBomUtf16LEPath).c_str());
+}
+
+TEST(MiscUtilsGroup, convert_if_not_utf8)
+{
+    auto _get_file_converted = [](const std::string& inFilepath)->std::string{
+        std::string ioString = Glib::file_get_contents(inFilepath);
+        CtStrUtil::convert_if_not_utf8(ioString, true/*sanitise*/);
+        return ioString;
+    };
+    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf8Path).c_str());
+    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf32BEPath).c_str());
+    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf32LEPath).c_str());
+    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf16BEPath).c_str());
+    ASSERT_STREQ("Привет\n", _get_file_converted(UT::testBomUtf16LEPath).c_str());
 }
 
 TEST(MiscUtilsGroup, is_str_true)
